!L578-580: carbon_tau definition, initialisation, usage
!L646: pool_tau(ncarb) 
!!Not sure whether all litter related loops should be ndeep or nbdl
!!SIMON: FROZEN RESP FUNCTION + RELATED CONTROL_TEMP_FUNC need to be included
!!To put in bulk dens calcs involves putting in moist_soil also not clear if this should be done.
!-->  If so then se can put in bulk dens from DOC but not clear..
! =================================================================================================================================
! MODULE       : stomate_litter 
!
! CONTACT      : orchidee-help _at_ listes.ipsl.fr
!
! LICENCE      : IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF       Update litter and lignine content after litter fall and 
!! calculating litter decomposition.      
!!
!!\n DESCRIPTION: None
!!
!! RECENT CHANGE(S): None
!!
!! REFERENCE(S)	: None
!!
!! SVN          :
!! $HeadURL$
!! $Date$
!! $Revision$
!! \n
!_ ================================================================================================================================

MODULE stomate_litter

  ! modules used:

  USE ioipsl_para
  USE stomate_data
  USE constantes
  USE constantes_soil
  USE pft_parameters
  USE stomate_soilcarbon

  IMPLICIT NONE

  ! private & public routines

  PRIVATE
  PUBLIC littercalc, littercalc_MICT, littercalc_clear, deadleaf
  LOGICAL, SAVE                                                   :: firstcall = .TRUE.

  LOGICAL, SAVE                                  :: firstcall_litter = .TRUE.       !! first call
!$OMP THREADPRIVATE(firstcall_litter)

  REAL(r_std), SAVE, DIMENSION(nparts,nlitt)     :: litterfrac         !! The fraction of leaves, wood, etc. that 
                                                                       !! goes into metabolic and structural 
                                                                       !! litterpools (0-1, unitless)
!$OMP THREADPRIVATE(litterfrac)
  REAL(r_std), SAVE, ALLOCATABLE, DIMENSION(:)   :: z_soil             !! Soil levels (m)
!$OMP THREADPRIVATE(z_soil)
  REAL(r_std), SAVE, DIMENSION(nlitt)            :: litter_tau         !! Turnover time in litter pools (days)
!$OMP THREADPRIVATE(litter_tau)
  REAL(r_std), SAVE, DIMENSION(npool)            :: pool_tau           !! Turnover time in litter and soil carbon pools (days)
!$OMP THREADPRIVATE(pool_tau)

!$OMP THREADPRIVATE(DOC_tau)
  INTEGER(i_std), SAVE                           :: frozen_respiration_func = 1

  LOGICAL, SAVE                                  :: use_snowinsul_litter_resp = .FALSE.

!!END SIMON ADD


!
  REAL(r_std), SAVE, DIMENSION(nlitt,ncarb,nlevs)             :: frac_soil          !! Fraction of litter that goes into soil 
                                                                                      !! (litter -> carbon, above and below). The
                                                                                      !! remaining part goes to the atmosphere
!$OMP THREADPRIVATE(frac_soil)
CONTAINS

!! ================================================================================================================================
!! SUBROUTINE   : littercalc_calc
!!
!!\BRIEF        Set the flag ::firstcall_litter to .TRUE. and as such activate section
!! 1.1 of the subroutine littercalc (see below).
!!
!! DESCRIPTION  : None
!!
!! RECENT CHANGE(S) : None
!!
!! MAIN OUTPUT VARIABLE(S) : None
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART : None
!! \n
!_ ================================================================================================================================

  SUBROUTINE littercalc_clear
    firstcall_litter =.TRUE.
  END SUBROUTINE littercalc_clear


!! ================================================================================================================================
!! SUBROUTINE   : littercalc
!!
!!\BRIEF        Calculation of the litter decomposition and therefore of the 
!! heterotrophic respiration from litter following Parton et al. (1987).
!!
!! DESCRIPTION  : The littercal routine splits the litter in 4 pools: 
!! aboveground metaboblic, aboveground structural, belowground metabolic and 
!! belowground structural. the fraction (F) of plant material going to metabolic 
!! and structural is defined following Parton et al. (1987). The below ground
!! litter is discretized over 11 layers (the same used by the CWRR hydrology
!! scheme).
!! \latexonly
!! \input{littercalc1.tex}
!! \endlatexonly
!! \n
!! where L is the lignin content of the plant carbon pools considered and CN 
!! its CN ratio. L and CN are fixed parameters for each plant carbon pools,
!! therefore it is the ratio between each plant carbon pool within a PFT, which
!! controlled the part of the total litter, that will be considered as
!! recalcitrant (i.e. structural litter) or labile (i.e. metabolic litter).\n  
!! 
!! The routine calculates the fraction of aboveground litter which is metabolic
!! or structural (the litterpart variable) which is then used in lpj_fire.f90.\n 
!! 
!! In the section 2, the routine calculate the new plant material entering the
!! litter pools by phenological death of plants organs (corresponding to the
!! variable turnover) and by fire, herbivory and others non phenological causes
!! (variable bm_to_litter). This calculation is first done for each PFT and then
!! the values calculated for each PFT are added up. Following the same approach
!! the lignin content of the total structural litter is calculated and will be
!! then used as a factor control of the decomposition of the structural litter
!! (lignin_struc) in the section 5.1.2. A test is performed to avoid that we add
!! more lignin than structural litter. Finally, the variable litterpart is
!! updated.\n
!! 
!! In the section 3 and 4 the temperature and the moisture controlling the
!! decomposition are calculated for above and belowground. For aboveground
!! litter, air temperature and litter moisture are calculated in sechiba and used 
!! directly. For belowground, soil temperature and moisture are also calculated 
!! in sechiba but are modulated as a function of the soil depth. The modulation 
!! is a multiplying factor exponentially distributed between 0 (in depth) and 1
!! in surface.\n  
!! 
!! Then, in the section 5, the routine calculates the structural litter decomposition 
!! (C) following first order kinetics following Parton et al. (1987).
!! \latexonly
!! \input{littercalc2.tex}
!! \endlatexonly
!! \n
!! with k the decomposition rate of the structural litter. 
!! k corresponds to
!! \latexonly
!! \input{littercalc3.tex}
!! \endlatexonly
!! \n
!! with littertau the turnover rate, T a function of the temperature and M a function of
!! the moisture described below.\n
!!  
!! Then, the fraction of dead leaves (DL) composed by aboveground structural litter is
!! calculated as following
!! \latexonly
!! \input{littercalc4.tex}
!! \endlatexonly
!! \n
!! with k the decomposition rate of the structural litter previously
!! described.\n
!!
!! In the section 5.1, the fraction of decomposed structural litter
!! incorporated to the soil (Input) and its associated heterotrophic respiration are
!! calculated. For structural litter, the C decomposed could go in the active
!! soil carbon pool or in the slow carbon, as described in 
!! stomate_soilcarbon.f90.\n
!! \latexonly
!! \input{littercalc5.tex}
!! \endlatexonly
!! \n
!! with f a parameter describing the fraction of structural litter incorporated
!! into the considered soil carbon pool, C the amount of litter decomposed and L 
!! the amount of lignin in the litter. The litter decomposed which is not
!! incorporated into the soil is respired.\n
!!
!! In the section 5.2, the fraction of decomposed metabolic litter
!! incorporated to the soil and its associated heterotrophic respiration are
!! calculated with the same approaches presented for 5.1 but no control factor
!! depending on the lignin content are used.\n
!! 
!! In the section 6 the dead leaf cover is calculated through a call to the 
!! deadleaf subroutine presented below.\n
!!
!! In the section 7, if the flag SPINUP_ANALYTIC is set to true, we fill MatrixA
!! and VectorB following Lardy(2011).
!!
!! MAIN OUTPUT VARIABLES: ::deadleaf_cover, ::resp_hetero_litter, ::soilcarbon_input, 
!! ::control_temp, ::control_moist
!!
!! REFERENCES:
!! - Parton, WJ, Schimel, DS, Cole, CV, and Ojima, DS. 1987. Analysis
!! of factors controlling soil organic matter levels in Great Plains
!! grasslands. Soil Science Society of America journal (USA)
!! (51):1173-1179.
!! - Lardy, R, et al., A new method to determine soil organic carbon equilibrium,
!! Environmental Modelling & Software (2011), doi:10.1016|j.envsoft.2011.05.016
!!
!! FLOWCHART    :
!! \latexonly
!! \includegraphics(scale=0.5){littercalcflow.jpg}
!! \endlatexonly
!! \n
!_ ================================================================================================================================

  SUBROUTINE littercalc (npts, &
       turnover, zz_coef_deep, bm_to_litter, &
       veget_max, tsurf, tsoil, soilhum, litterhum, rprof, &
       litterpart, litter_above, litter_below, litter_avail, litter_not_avail, litter_avail_frac, &
       fuel_1hr, fuel_10hr, fuel_100hr, fuel_1000hr, &
       dead_leaves, lignin_struc_above, lignin_struc_below, &
       deadleaf_cover, resp_hetero_litter, resp_hetero_flood, &
       soilcarbon_input, soilcarbon_input_DOC, floodcarbon_input, control_temp_below, control_moist_above, &
       clay, bulk_dens, soil_ph, poor_soils, tprof, carbon_32l, fbact, flood_frac,  &
!END ORCHIDOC
       soil_mc, MatrixA, VectorB, &
!!!!!crops
       tsoil_cm, soilhum_cm, &
!!!!!xuhui
!gmjc
       sla_calc,do_slow)
!end gmjc

    !! 0. Variable and parameter declaration
!
    !! 0.1 Input variables
!    INTEGER(i_std), INTENT(in)			               :: dayno            !! number of the day in the current yea!r
    INTEGER(i_std), INTENT(in)                                  :: npts               !! Domain size - number of grid pixels
                                                                                       !! @tex $(dtradia one\_day^{-1})$ @endtex 
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements), INTENT(in) :: turnover           !! Turnover rates of plant biomass 
                                                                                      !! @tex $(gC m^{-2} dt\_slow^{-1})$ @endtex 
    REAL(r_std), DIMENSION(ndeep),   INTENT (in)          :: zz_coef_deep      !! deep vertical profile
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements), INTENT(in) :: bm_to_litter     !! Conversion of biomass to litter 
                                                                                      !! @tex $(gC m^{-2} dt\_slow^{-1})$ @endtex 
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)                  :: veget_max          !! PFT "Maximal" coverage fraction of a PFT 
                                                                                      !! defined in the input vegetation map 
                                                                                      !! @tex $(m^2 m^{-2})$ @endtex 
    REAL(r_std), DIMENSION(npts), INTENT(in)                    :: tsurf              !! Temperature (K) at the surface
    REAL(r_std), DIMENSION(npts,nbdl), INTENT(in)               :: tsoil              !! Soil temperature (K)
    REAL(r_std), DIMENSION(npts,nbdl), INTENT(in)               :: soilhum            !! Daily soil humidity of each soil layer 
                                                                                      !! (unitless)
    REAL(r_std), DIMENSION(npts), INTENT(in)                    :: litterhum          !! Daily litter humidity (unitless)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)                 :: rprof              !! PFT root depth as calculated in stomate.f90 from parameter 
    REAL(r_std),DIMENSION (npts,nbdl,nstm), INTENT(in)           :: soil_mc            !! soil moisture content \f($m^3 \times m^3$)\f
    REAL(r_std), DIMENSION(npts), INTENT(in)                     :: clay               !! Clay fraction (unitless, 0-1) 
    REAL(r_std), DIMENSION(npts), INTENT(inout)                  :: bulk_dens          !! Variable local of bulk density for the moment must change in the futur (kg m-3)

    REAL(r_std), DIMENSION(npts), INTENT(in)                     :: soil_ph            !! soil pH (pH unit, 0-14)
    REAL(r_std), DIMENSION(npts), INTENT(in)                     :: poor_soils         !! Fraction of poor soils (0-1)
    !!!SIMON added these 3 variables (2 new, 1 from permafrost soilcarbon) to make carbon, hydro, energy consistent with 32 layer expressions
    REAL(r_std), DIMENSION(npts,ndeep,nvm), INTENT(in)       :: tprof              !! Soil temperature (K)
!!    REAL(r_std),DIMENSION (npts,ndeep,nstm), INTENT(in)           :: soil_mc_32l            !! soil moisture content \f($m^3 \times m^3$)\f
    REAL(r_std), DIMENSION(npts,ncarb,nvm,ndeep), INTENT(in)      :: carbon_32l             !! Soil carbon pools: active, slow, or passive, \f$(gC m^{2})$\f
    REAL(r_std), DIMENSION(npts,ndeep,nvm), INTENT(in) 		  :: fbact
    REAL(r_std), DIMENSION(npts), INTENT(in)                     :: flood_frac         !! flooded fraction, needed to calculate heterotrophic respiration input to floodplain
!JCADD
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)                  :: sla_calc
    LOGICAL,INTENT(in)                               :: do_slow
!ENDJCADD   


    !! 0.2 Output variables
    
    REAL(r_std), DIMENSION(npts), INTENT(out)                   :: deadleaf_cover     !! Fraction of soil covered by dead leaves 
                                                                                      !! over all PFTs (0-1, unitless)
    REAL(r_std), DIMENSION(npts,nvm,nlevs), INTENT(out)          :: resp_hetero_litter !! Litter heterotrophic respiration. The unit
                                                                                      !! is given by m^2 of ground.  
                                                                                      !! @tex $(gC dt_sechiba one\_day^{-1}) m^{-2})$ @endtex 
  REAL(r_std), DIMENSION(npts,nvm), INTENT(out)               :: resp_hetero_flood
     REAL(r_std), DIMENSION(npts,ncarb,nvm), INTENT(out)         :: soilcarbon_input   !! Quantity of carbon going into carbon pools
!                                                                                       !! from litter decomposition. The unit is  
!                                                                                       !! given by m^2 of ground 
!                                                                                       !! @tex $(gC m^{-2} dt\_slow^{-1})$ @endtex 
    !REAL(r_std), DIMENSION(npts,nlevs), INTENT(out)             :: control_temp       !! Temperature control of heterotrophic 
                                                                                      !! respiration, above and below (0-1, 
                                                                                      !! unitless)
    !REAL(r_std), DIMENSION(npts,nlevs), INTENT(out)             :: control_moist      !! Moisture control of heterotrophic 
!!!SIMON ADDED FROM ORCHIDOC                                                                                      !! respiration (0.25-1, unitless)
    REAL(r_std), DIMENSION(npts,ndeep,npool*2,nvm), INTENT(out)       :: control_temp_below !! Temperature control of heterotrophic
                                                                                       !! respiration belowground,(0-1, unitless)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)                :: control_moist_above!! Moisture control of heterotrophic  
                                                                                       !! respiration aboveground(0.25-1, unitless)
!!!SIMON END
    
    REAL(r_std), DIMENSION(npts,nvm,npool,npool), INTENT(out) :: MatrixA          !! Matrix containing the fluxes between the
                                                                                      !! carbon pools per sechiba time step 
                                                                                      !! @tex $(gC.m^2.day^{-1})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,npool), INTENT(out)         :: VectorB          !! Vector containing the litter increase per
                                                                                      !! sechiba time step
                                                                                      !! @tex $(gC m^{-2})$ @endtex

!!!!! crops
    ! soil temperature at the resolution of 1 cm, the second dimension is 3
    ! according to the STICS code. That represent the 3 layers around sowing
    ! depth
    REAL(r_std), DIMENSION(npts, nvm, 3), INTENT(inout)           :: tsoil_cm
    ! soil relative humidity at the resolution of 1 cm, the second dimension is
    ! 3
    ! according to the STICS code. That represent the 3 layers around sowing
    ! depth
    REAL(r_std), DIMENSION(npts, nvm, 3), INTENT(inout)           :: soilhum_cm
!!!!! end crops, xuhui
   
    !! 0.3 Modified variables
    
    REAL(r_std), DIMENSION(npts,nvm,ndeep,npool,nelements), INTENT(inout) :: soilcarbon_input_DOC !! Dissolved Organic Carbon input from litter decomposition
                                                                                      !! The unit is given by m^2
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,npool,nelements), INTENT(inout) :: floodcarbon_input
!
    REAL(r_std), DIMENSION(npts,nvm,nlitt), INTENT(inout)       :: litterpart         !! Fraction of litter above the ground 
                                                                                      !! belonging to the different PFTs (0-1, 
                                                                                      !! unitless)
    REAL(r_std), DIMENSION(npts,nlitt,nvm,nelements), INTENT(inout) :: litter_above   !! Metabolic and structural litter,above and
                                                                                      !! below ground. The unit is given by m^2 of 
                                                                                      !! ground @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nlitt,nvm,ndeep,nelements), INTENT(inout) :: litter_below   !! Metabolic and structural litter,above and
!   
    REAL(r_std), DIMENSION(npts,nlitt,nvm), INTENT(inout)       :: litter_avail
    REAL(r_std), DIMENSION(npts,nlitt,nvm), INTENT(in)       :: litter_not_avail
    REAL(r_std), DIMENSION(npts,nlitt,nvm), INTENT(out)       :: litter_avail_frac

    REAL(r_std), DIMENSION(npts,nvm,nlitt), INTENT(inout)       :: dead_leaves        !! Dead leaves per ground unit area, per PFT,
                                                                                      !! metabolic and structural in 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)            :: lignin_struc_above  !! Ratio Lignin content in structural litter,
                                                                                      !! above ground, (0-1, unitless)
    REAL(r_std), DIMENSION(npts,nvm,ndeep), INTENT(inout)       :: lignin_struc_below  !! Ratio Lignin content in structural litter,
                                                                                 !! above and below ground, (0-1, unitless)
!spitfire
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements),INTENT(inout)        :: fuel_1hr
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements),INTENT(inout)        :: fuel_10hr
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements),INTENT(inout)        :: fuel_100hr
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements),INTENT(inout)        :: fuel_1000hr
!end spitfire

    !! 0.4 Local variables
!!!SIMON ADDED FROM ORCHIDOC and MICT deepcarb
!!
	
	LOGICAL, SAVE                    :: ok_cryoturb               !! cryoturbate the carbon?
    REAL(r_std), DIMENSION(0:ndeep)                              :: zf_soil              !! Variable to store depth of the different
    REAL(r_std), SAVE, DIMENSION(ncarb)      			:: carbon_tau       !! Residence time in carbon pools (days)
    REAL(r_std), DIMENSION(npts,ndeep,nvm)			  :: fbact_a
    REAL(r_std), DIMENSION(npts,ndeep,nvm)			  :: fbact_met
    REAL(r_std), DIMENSION(npts,ndeep,nvm)			  :: fbact_str
!!
    REAL(r_std), DIMENSION(npts)                                :: fd_flood           !! Fraction of structural or metabolic litter
                                                                                      !! decomposed in flooded areas (unitless)
    REAL(r_std), DIMENSION(npts,nvm)                            :: control_flood_above!! Moisture control of heterotrophic
                                                                                      !! respiration aboveground(0.25-1, unitless)
    REAL(r_std)                                                 :: dt                 !! Time step of the simulations for stomate
                                                                                      !! @tex $(dt_sechiba one\_day^{-1})$ @endtex 
    REAL(r_std), DIMENSION(npts,nparts,nlitt)                   :: litterfrac_pxl     !! The fraction of leaves, wood, etc. that
                                                                                      !! goes into metabolic and structural
                                                                                      !! litterpools (0-1, unitless)
    REAL(r_std), DIMENSION(npts)                                :: rpc                !! Integration constant for vertical root 
                                                                                      !! profiles (unitless)
!!END SIMON ADD
    REAL(r_std), DIMENSION(npts)                                :: tsoil_decomp       !! Temperature used for decompostition in 
                                                                                      !! soil (K)
    REAL(r_std), DIMENSION(npts)                                :: soilhum_decomp     !! Humidity used for decompostition in soil
                                                                                      !! (unitless)
    REAL(r_std), DIMENSION(npts)                                :: fd                 !! Fraction of structural or metabolic litter
                                                                                      !! decomposed (unitless)
    REAL(r_std), DIMENSION(npts,nelements)                      :: qd                 !! Quantity of structural or metabolic litter
 !!!SIMON ORCHIDOC   
!! decomposed @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nelements)                      :: qd_flood           !! Quantity of structural or metabolic litter
                                                                                      !! decomposed in flooded areas @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm)                            :: old_struc_above    !! Old structural litter, above ground 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,ndeep)                       :: old_struc_below     
    REAL(r_std), DIMENSION(npts)                                :: Dif_coef           !! Diffusion coeficient used for bioturbation (m2 days-1)
!!$OMP THREADPRIVATE(Dif_coef)
    REAL(r_std), DIMENSION(npts,nlitt,nvm,ndeep,nelements)       :: litter_flux        !! Belowground litter carbon flux within pools towards the soil column\f$(gC m^{2} dt^{-1})$\f
    REAL(r_std), DIMENSION(npts,nlitt,nvm,ndeep,nelements)       :: litter_flux_old    !! Belowground litter carbon flux within pools towards the soil column\f$(gC m^{2} dt^{-1})$\f
                                                                                      !! used for storage
    REAL(r_std), DIMENSION(npts,nlitt,nvm,nelements)            :: litter_above_flux  !! Above litter carbon flux within pools towards the soil column\f$(gC m^{2} dt^{-1})$\f 
    REAL(r_std), DIMENSION(npts,nlitt,nvm,nelements)            :: litter_above_flux_old  !! Above litter carbon flux within pools towards the soil column\f$(gC m^{2} dt^{-1})$\f
!                                                                                      
!!!SIMONEND ORCHIDOC                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nlevs,nelements)      :: litter_inc_PFT     !! Increase of litter, per PFT, metabolic and
                                                                                      !! structural, above and below ground. The 
                                                                                      !! unit is given by m^2 of ground.  
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nlitt,nvm,nlevs,nelements)      :: litter_inc         !! Increase of metabolic and structural 
                                                                                      !! litter, above and below ground. The unit 
                                                                                      !! is given by m^2 of ground. 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlevs)                      :: lignin_struc_inc   !! Lignin increase in structural litter, 
                                                                                      !! above and below ground. The unit is given 
    !!! SIMON ADDED FROM ORCHIDOC
    
    REAL(r_std), DIMENSION(npts,nvm,nlitt, nelements)           :: litter_inc_PFT_above  !! Increase of litter, per PFT, metabolic and
                                                                                      !! structural, above ground. The 
                                                                                      !! unit is given by m^2 of ground.  
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlitt,ndeep,nelements)      :: litter_inc_PFT_below     !! Increase of litter, per PFT, metabolic and
                                                                                      !! structural, above ground. The 
                                                                                      !!unit is given by m^2 of ground.
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nlitt,nvm,nelements)            :: litter_inc_above   !! Increase of metabolic and structural 
                                                                                      !! litter, above ground. The unit 
                                                                                      !! is given by m^2 of ground. 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nlitt,nvm,ndeep,nelements)       :: litter_inc_below   !! Increase of metabolic and structural 
                                                                                      !! litter below ground. The unit
                                                                                      !! is given by m^2 of ground
                                                                                      !! @tex $(gC m^{-2})$ @endtex

    REAL(r_std), DIMENSION(npts,nvm)                            :: lignin_struc_inc_above !! Lignin increase in structural litter, 
                                                                                      !! above ground. The unit is given 
                                                                                      !! by m^2 of ground. 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,ndeep)                       :: lignin_struc_inc_below   !! Lignin increase in structural litter, 
                                                                                      !! below ground. The unit is given
                                                                                      !! @tex $(gC m^{-2})$ @endtex                                                                                  !! by m^2 of ground. 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements)            :: litter_pft         !! Metabolic and structural litter above the 
                                                                                      !! ground per PFT
    REAL(r_std), DIMENSION(npts)                                :: zdiff_min          !! Intermediate field for looking for minimum
                                                                                      !! of what? this is not used in the code. 
                                                                                      !! [??CHECK] could we delete it?
    CHARACTER(LEN=10), DIMENSION(nlitt)                         :: litter_str         !! Messages to write output information about
                                                                                      !! the litter
    CHARACTER(LEN=22), DIMENSION(nparts)                        :: part_str           !! Messages to write output information about
                                                                                      !! the plant
    CHARACTER(LEN=7), DIMENSION(ncarb)                          :: carbon_str         !! Messages to write output information about
                                                                                      !! the soil carbon
    CHARACTER(LEN=5), DIMENSION(nlevs)                          :: level_str          !! Messages to write output information about
                                                                                      !! the level (aboveground or belowground litter)
    INTEGER(i_std)                                              :: i,j,k,l,m          !! Indices (unitless)

!spitfire
    !total fuel load summing together all fuel classes.
    REAl(r_std), DIMENSION(npts,nvm,nlitt,nelements)                      :: fuel_nlitt_total_pft
    ! difference between litter and fuel_nlitt_total_pft
    REAL(r_std), DIMENSION(npts)                                :: diff_frac
    ! quantity of structural or metabolic litter decomposed (gC/m**2) for decomposing fuel classes per PFT
    ! chaocomm: this is now only a temporary variable and will be deleted later.
    REAL(r_std), DIMENSION(npts,nelements)                                :: qd_fuel
!endspit
    

  ! 
    REAL(r_std), DIMENSION(npts,nlitt,nvm,ndeep,nelements)  ::litter_below_old         !! Metabolic and structural litter, below ground
                                                                                      !! The unit is given by m^2 of
                                                                                      !! ground @tex $(gC m^{-2} $ @endtex used for storage
    REAL(r_std), DIMENSION(npts,nlitt,nvm,ndeep,nelements)  ::litter_below_old_buffer  !! Metabolic and structural litter, below ground
                                                                                      !! The unit is given by m^2 of
    REAL(r_std), DIMENSION(npts,nlitt,nvm,nelements)       :: litter_above_old        !! Metabolic and structural litter,above ground
                                                                                      !! The unit is given by m^2 of 
                                                                                                                                                                                
!!!!! crops
    ! local variables
    ! three layer around the sowing depth, in cm 
    REAL(r_std), DIMENSION(nvm, 3)                                      :: ldep

    ! the nth of half layer,[1, 2, .....2*nbdl]
    INTEGER(i_std)                                                    :: nhl
    ! the upper limit humidity for ith half layer of 22 half layers, 2*nbdl
    INTEGER(i_std), DIMENSION(npts, 2*nbdl)                                   :: ulhum
    ! the ith layer for the three layers around sowing depth
    INTEGER(i_std)                                                    :: il
    ! uldep is the upper limit of ith half layer of 22 half layers, 2*nbdl
    !REAL(r_std), DIMENSION(2*nbdl)                                  :: uldep
    REAL(r_std)                                                     :: uldep
    ! bldep is the lower limit of ith half layer of 22 half layers
    REAL(r_std)                                                     :: bldep
    
    ! the upper limit soil temperature for ith half layer of 22 half layers, 2*nbdl
    REAL(r_std), DIMENSION(npts, 2*nbdl)                                   :: ultsoil
    ! identifier for number of PFTs
    INTEGER(i_std)                                                    :: ipft
!!!!! end crops

    INTEGER(i_std)                                              :: ier                !! Error handling
    REAL(r_std), DIMENSION(npts)                           :: one_array               !!From ORCHIDOC (no def)
    REAL(r_std), DIMENSION(npts,nvm,nelements)              ::pool_start
    REAL(r_std), DIMENSION(npts,nvm,nelements)             :: pool_end            !! End pool of this routine not corrected
                                                                                      !! @tex $(gC pixel^{-1} dt^{-1})$ @endtex 
    REAL(r_std), DIMENSION(npts,nvm,nelements)             :: pool_end_after          !! Start and end pool of this routine 
                                                                                      !! @tex $(gC pixel^{-1} dt^{-1})$ @endtex 

    REAL(r_std), DIMENSION(npts,nlitt)              :: control_temp_above             !! Temperature control of heterotrophic
                                                                                      !! respiration, above (0-1,
                                                                                      !! unitless)
    REAL(r_std), DIMENSION(npts,nvm,nmbcomp,nelements)     :: check_intern              !! Contains the components of the internal
                                                                                      !! mass balance chech for this routine
                                                                                      !! @tex $(gC pixel^{-1} dt^{-1})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nelements)             :: closure_intern     !! Check closure of internal mass balance


!_ ================================================================================================================================

    IF (printlev>=3) WRITE(numout,*) 'Entering littercalc'

    !! 0. Initialise output variables 
    deadleaf_cover = zero
    resp_hetero_litter = zero
    resp_hetero_flood = zero
    soilcarbon_input = zero
    control_temp_below = zero 
    control_moist_above = zero
    MatrixA = zero
    VectorB = zero
    litter_avail_frac = zero

    !! 0.1 Initialise local variables
 !   soil_mc_32l = zero
    fd_flood = zero
    control_flood_above = zero
    litterfrac_pxl = zero
    rpc = zero
    tsoil_decomp = zero
    soilhum_decomp = zero
    fd = zero
    qd = zero
    qd_flood = zero
    old_struc_above = zero
    old_struc_below = zero
    Dif_coef = zero
    litter_flux = zero
    litter_flux_old = zero
    litter_above_flux = zero
    litter_above_flux_old = zero
    litter_inc_PFT = zero
    litter_inc = zero
    lignin_struc_inc = zero

    litter_inc_PFT_above = zero
    litter_inc_PFT_below = zero
    litter_inc_above = zero
    litter_inc_below = zero
    lignin_struc_inc_above = zero
    lignin_struc_inc_below = zero
    
    litter_pft = zero
    zdiff_min = zero
    fuel_nlitt_total_pft = zero
    qd_fuel = zero

    litter_below_old = zero
    litter_below_old_buffer = zero
    litter_above_old = zero
    one_array = zero
    pool_start = zero
    pool_end = zero
    pool_end_after = zero
    control_temp_above = zero
    check_intern = zero
    closure_intern = zero
  !! 1. Initialisations of the different fields during the first call of the routine 
    dt = dt_sechiba/one_day
    diff_frac(:) = 0
!!!SIMON ADDED ORCHIDOC --COMMENTED segments are ORCHIDOC to be merged in

    !! 1.0 Calculation of soil moisture
!     moist_soil(:,:) = zero
!       DO l = 1,nbdl
!           DO i = 1, nstm
!              moist_soil(:,l)= moist_soil(:,l) + soil_mc(:,l,i)*soiltile(:,i)
!           ENDDO
!       ENDDO
! 
!!Calc for soil_mc_32l
!	soil_mc_32l(:,1:11,:) = soil_mc(:,:,:)
!	soil_mc_32l(:,12:32,:) = soil_mc(:,11,:)
!!SIMON ADDED fbact and zf_soil from MICT nomenclature
   zf_soil(:) = zero
   zf_soil(1:ndeep) = zz_coef_deep(:)
   zf_soil(0) = 0.
!!!%%%
!!!now fbact
   fbact_a = zero
   fbact_a = fbact(:,:,:)
   fbact_met = zero	
   fbact_str = zero
   carbon_tau(:) = zero
   carbon_tau(iactive) = carbon_tau_iactive * one_year       ! 1.5 years. This is same as CENTURY. 
   carbon_tau(islow) = carbon_tau_islow * one_year       ! 25 years. This is same as CENTURY. 
   carbon_tau(ipassive) = carbon_tau_ipassive * one_year       ! 1000 years. This is same as CENTURY. 
!
       litter_tau(imetabolic) = tau_metabolic * one_year      ! .5 years
       litter_tau(istructural) = tau_struct * one_year     ! 3 years


   fbact_met = fbact_a * (carbon_tau(iactive)/litter_tau(imetabolic))  
   
DO m = 1,nvm
	DO l = 1,ndeep
	     fbact_str(:,l,m) = fbact_a(:,l,m) * (carbon_tau(iactive)/litter_tau(istructural))* exp(-litter_struct_coef * lignin_struc_below(:,m,l) )
	END DO
END DO
!   
!!!!!!!!!!!!!!!    fbact_p = fbact_a *  (litter_tau_ipassive/litter_tau_iactive)
! 
    WHERE (bulk_dens(:) .LT. 500)
    bulk_dens(:) = bulk_dens(:)*1e3
    ENDWHERE


    !! 1.1 Initialize check for mass balance closure
    !  The mass balance is calculated at the end of this routine
    !  in section 14. Initial biomass and harvest pool and all other
    !  relevant pools were set to zero before calling this routine.
     pool_start(:,:,:) = zero
!!SIMON ADDED DOC POOLS
IF (ld_doc) THEN
    DO m = 2, nvm
       DO i = 1,nlitt
          DO l = 1, ndeep
                 pool_start(:,m,icarbon) = pool_start(:,m,icarbon) + &
                           ( litter_below(:,i,m,l,icarbon) ) * veget_max(:,m)
          ENDDO
       ENDDO
    ENDDO

    DO m = 2, nvm
       DO i = 1,nlitt
                 pool_start(:,m,icarbon) = pool_start(:,m,icarbon) + &
                           ( litter_above(:,i,m,icarbon) ) * veget_max(:,m)
       ENDDO
    ENDDO

    DO m = 2, nvm
       DO i = 1, nparts
          pool_start(:,m,icarbon) = pool_start(:,m,icarbon) + &
                    (turnover(:,m,i,icarbon) + bm_to_litter(:,m,i,icarbon)) * veget_max(:,m)
      ENDDO
    ENDDO
ENDIF
!!!SIMON ORCHIDOC END
!
!  
    IF ( firstcall_litter ) THEN

       !! 1.1.3 litter fractions:
       !!   what fraction of leaves, wood, etc. goes into metabolic and structural litterpools
       DO k = 1, nparts

          litterfrac(k,imetabolic) = metabolic_ref_frac - metabolic_LN_ratio * LC(k) * CN(k)
          litterfrac(k,istructural) = un - litterfrac(k,imetabolic)

       ENDDO

       !! 1.1.4 residence times in litter pools (days)

!!!SIMON ADDED ORCHIDOC
!	  pool_tau(imetabo) = tau_metabolic 
!       pool_tau(istrabo) = tau_struct 
!       pool_tau(imetbel) = tau_metabolic 
!       pool_tau(istrbel) = tau_struct 
!       pool_tau(iact) = carbon_tau_iactive 
!       pool_tau(islo) = carbon_tau_islow 
!       pool_tau(ipas) = carbon_tau_ipassive 
!!!SIMON HERE DBL CHECK WE SHOULDNT DIVIDE BY 1 YEAR 
!       DOC_tau = zero      
!       DOC_tau(:,imetabo,:,:) = fbact_doc(:,:,:)
!       DOC_tau(:,istrabo,:,:) = fbact_doc(:,:,:) 
!       DOC_tau(,imetbel,:,:) = fbact_doc(:,:,:) 
!       DOC_tau(:,istrbel,:,:) = fbact_doc(:,:,:) 
!       DOC_tau(:,iact,:,:) = fbact_doc(:,:,:) 
!       DOC_tau(:,islo,:,:) = fbact_doc*(DOC_tau_stable/DOC_tau_labile)  
!       DOC_tau(:,ipas,:,:) = fbact_doc*(DOC_tau_stable/DOC_tau_labile)  



!!!THIS IS ORIGINAL ORCHILEAK
!!!DOC_tau(imetabo) = DOC_tau_labile / one_year
!!!DOC_tau(istrabo) = DOC_tau_labile / one_year
!!!DOC_tau(imetbel) = DOC_tau_labile / one_year
!!!DOC_tau(istrbel) = DOC_tau_labile / one_year
!!!DOC_tau(iact) = DOC_tau_labile / one_year
!!!DOC_tau(islo) = DOC_tau_stable / one_year
!!!DOC_tau(ipas) = DOC_tau_stable / one_year
!!!
!!END SIMON ADDED ORCHIDOC
       !! 1.1.5 decomposition flux fraction that goes into soil
       !       (litter -> carbon, above and below)
       !       1-frac_soil goes into atmosphere
       frac_soil(:,:,:) = zero

       ! structural litter: lignin fraction goes into slow pool + respiration,
       !                    rest into active pool + respiration
       frac_soil(istructural,iactive,iabove) = frac_soil_struct_aa
       frac_soil(istructural,iactive,ibelow) = frac_soil_struct_ab
       frac_soil(istructural,islow,iabove) = frac_soil_struct_sa
       frac_soil(istructural,islow,ibelow) = frac_soil_struct_sb

       ! metabolic litter: all goes into active pool + respiration.
       !   Nothing into slow or passive pool.
       frac_soil(imetabolic,iactive,iabove) = frac_soil_metab_aa
       frac_soil(imetabolic,iactive,ibelow) = frac_soil_metab_ab

       
       !! 1.2 soil levels
       ALLOCATE(z_soil(0:nbdl), stat=ier)
       IF ( ier /= 0 ) CALL ipslerr_p(3,'littercalc','Pb in allocate of z_soil','','')

       z_soil(0) = zero
       z_soil(1:nbdl) = diaglev(1:nbdl)

       
       !! 1.3 messages
       litter_str(imetabolic) = 'metabolic'
       litter_str(istructural) = 'structural'

       carbon_str(iactive) = 'active'
       carbon_str(islow) = 'slow'
       carbon_str(ipassive) = 'passive'

       level_str(iabove) = 'above'
       level_str(ibelow) = 'below'

       part_str(ileaf) = 'leaves'
       part_str(isapabove) = 'sap above ground'
       part_str(isapbelow) = 'sap below ground'
       part_str(iheartabove) = 'heartwood above ground'
       part_str(iheartbelow) = 'heartwood below ground'
       part_str(iroot) = 'roots'
       part_str(ifruit) = 'fruits'
       part_str(icarbres) = 'carbohydrate reserve'

       WRITE(numout,*) 'litter:'

       WRITE(numout,*) '   > C/N ratios: '
       DO k = 1, nparts
          WRITE(numout,*) '       ', part_str(k), ': ',CN(k)
       ENDDO

       WRITE(numout,*) '   > Lignine/C ratios: '
       DO k = 1, nparts
          WRITE(numout,*) '       ', part_str(k), ': ',LC(k)
       ENDDO

       WRITE(numout,*) '   > fraction of compartment that goes into litter: '
       DO k = 1, nparts
          DO m = 1, nlitt
             WRITE(numout,*) '       ', part_str(k), '-> ',litter_str(m), ':',litterfrac(k,m)
          ENDDO
       ENDDO

       WRITE(numout,*) '   > scaling depth for decomposition (m): ',z_decomp

       WRITE(numout,*) '   > minimal carbon residence time in litter pools (d):'
       DO m = 1, nlitt
          WRITE(numout,*) '       ',litter_str(m),':',litter_tau(m)
       ENDDO

       WRITE(numout,*) '   > litter decomposition flux fraction that really goes '
       WRITE(numout,*) '     into carbon pools (rest into the atmosphere):'
       DO m = 1, nlitt
          DO l = 1, nlevs
             DO k = 1, ncarb
                WRITE(numout,*) '       ',litter_str(m),' ',level_str(l),' -> ',&
                     carbon_str(k),':', frac_soil(m,k,l)
             ENDDO
          ENDDO
       ENDDO

       CALL getin_p('frozen_respiration_func',frozen_respiration_func)
       WRITE(numout, *)' frozen litter respiration function: ', frozen_respiration_func

       CALL getin_p('use_snowinsul_litter_resp',use_snowinsul_litter_resp)
       WRITE(numout, *)' use_snowinsul_litter_resp ( i.e. set surface litter temp to below snow layer:) ', use_snowinsul_litter_resp

       firstcall_litter = .FALSE.

    ENDIF ! ( firstcall_litter ) THEN


    !! 1.3 Initialization

       DO k = 1, nparts

          litterfrac_pxl(:,k,imetabolic) = metabolic_ref_frac - metabolic_LN_ratio * LC(k) * CN(k)! * (un + poor_soils(:))
          litterfrac_pxl(:,k,istructural) = un - litterfrac_pxl(:,k,imetabolic)

       ENDDO


    
    !! 1.3 litter above the ground per PFT.
    DO j = 2, nvm ! Loop over # PFTs

       DO k = 1, nlitt !Loop over litter pool
          litter_pft(:,j,k,icarbon) = litterpart(:,j,k) * litter_above(:,k,j,icarbon)
       ENDDO
    ENDDO
 
    DO j = 2, nvm ! Loop over # PFTs
       DO k = 1, nlitt !Loop over litter pool
          litter_pft(:,j,k,icarbon) = litterpart(:,j,k) * litter_above(:,k,j,icarbon)
       ENDDO
    ENDDO
 
    !! 1.4 set output to zero
    deadleaf_cover(:) = zero
    resp_hetero_litter(:,:,:) = zero
    resp_hetero_flood(:,:) = zero
!!!SIMON ORCHIDOC
!    soilcarbon_input(:,:,:) = 0.0
    soilcarbon_input_DOC(:,:,:,:,:) = 0.0
    floodcarbon_input(:,:,:,:)= zero


	old_struc_above(:,:) = zero
    old_struc_below(:,:,:) = zero
    litter_pft(:,:,:,:) = zero
    Dif_coef(:) = (Dif/one_year)*dt 

	!!!END SIMON ORCHIDOC

  !! 2. Add biomass to different litterpools (per m^2 of ground)
    
    !! 2.1 first, save old structural litter (needed for lignin fractions).
!!!SIMON ORCHIDOC


       DO m = 2,nvm !Loop over PFTs

          old_struc_above(:,m) = litter_above(:,istructural,m,icarbon)

       ENDDO       

    DO l = 1, ndeep !Loop over soil levels (below ground)
       DO m = 2,nvm !Loop over PFTs

          old_struc_below(:,m,l) = litter_below(:,istructural,m,l,icarbon)

       ENDDO
    ENDDO
  

    
    !! 2.2 update litter, dead leaves, and lignin content in structural litter
    !litter_inc(:,:,:,:,:) = zero
    !lignin_struc_inc(:,:,:) = zero
    litter_inc_above(:,:,:,:) = zero
    lignin_struc_inc_above(:,:) = zero
    litter_inc_below(:,:,:,:,:) = zero
    lignin_struc_inc_below(:,:,:) = zero
    litter_inc_PFT_above(:,:,:,:) = zero
    litter_inc_PFT_below(:,:,:,:,:) = zero

    DO j = 2,nvm !Loop over PFTs

       !! 2.2.1 litter
       DO k = 1, nlitt    !Loop over litter pools (metabolic and structural)
          ! For the first litter layer
          litter_inc_PFT_above(:,j,k,icarbon) = &
               litterfrac_pxl(:,ileaf,k) * bm_to_litter(:,j,ileaf,icarbon) + &
               litterfrac_pxl(:,isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
               litterfrac_pxl(:,iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
               litterfrac_pxl(:,ifruit,k) * bm_to_litter(:,j,ifruit,icarbon) + &
               litterfrac_pxl(:,icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
               litterfrac_pxl(:,ileaf,k) * turnover(:,j,ileaf,icarbon) + &
               litterfrac_pxl(:,isapabove,k) * turnover(:,j,isapabove,icarbon) + &
               litterfrac_pxl(:,iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
               litterfrac_pxl(:,ifruit,k) * turnover(:,j,ifruit,icarbon) + &
               litterfrac_pxl(:,icarbres,k) * turnover(:,j,icarbres,icarbon) 

             ! litter increase, met/struct, above
             litter_inc_above(:,k,j,icarbon) = litter_inc_above(:,k,j,icarbon) + litter_inc_PFT_above(:,j,k,icarbon)

          !! The function used for root profile is coming from stomate_npp.f90
       rpc(:) = un /( ( un - EXP( -z_soil(nbdl) / rprof(:,j) )) ) 
          DO l = 1, nbdl

             litter_inc_PFT_below(:,j,k,l,icarbon) = &
                  litterfrac_pxl(:,isapbelow,k) * bm_to_litter(:,j,isapbelow,icarbon) *  &
               rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  litterfrac_pxl(:,iheartbelow,k) * bm_to_litter(:,j,iheartbelow,icarbon) * &
               rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  litterfrac_pxl(:,iroot,k) * bm_to_litter(:,j,iroot,icarbon) * &
               rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  litterfrac_pxl(:,isapbelow,k) * turnover(:,j,isapbelow,icarbon) * &
               rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  litterfrac_pxl(:,iheartbelow,k) * turnover(:,j,iheartbelow,icarbon) * &
               rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  litterfrac_pxl(:,iroot,k) * turnover(:,j,iroot,icarbon) * &
               rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) )
             ! litter increase, met/struct, below
             litter_inc_below(:,k,j,l,icarbon) = litter_inc_below(:,k,j,l,icarbon) + litter_inc_PFT_below(:,j,k,l,icarbon)
          ENDDO
         
          !! 2.2.3 dead leaves, for soil cover.
          dead_leaves(:,j,k) = &
               dead_leaves(:,j,k) + &
               litterfrac_pxl(:,ileaf,k) * ( bm_to_litter(:,j,ileaf,icarbon) + turnover(:,j,ileaf,icarbon) )

          !! 2.2.4 lignin increase in structural litter
          IF ( k .EQ. istructural ) THEN

             lignin_struc_inc_above(:,j) = &
                  lignin_struc_inc_above(:,j) + &
                  LC(ileaf) * bm_to_litter(:,j,ileaf,icarbon) + &
                  LC(isapabove) * bm_to_litter(:,j,isapabove,icarbon) + &
                  LC(iheartabove) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  LC(ifruit) * bm_to_litter(:,j,ifruit,icarbon) + &
                  LC(icarbres) * bm_to_litter(:,j,icarbres,icarbon) + &
                  LC(ileaf) * turnover(:,j,ileaf,icarbon) + &
                  LC(isapabove) * turnover(:,j,isapabove,icarbon) + &
                  LC(iheartabove) * turnover(:,j,iheartabove,icarbon) + &
                  LC(ifruit) * turnover(:,j,ifruit,icarbon) + &
                  LC(icarbres) * turnover(:,j,icarbres,icarbon) 
            !! The function used for root profile is coming from stomate_npp.f90
            DO l = 1, nbdl

               lignin_struc_inc_below(:,j,l) = &
                  lignin_struc_inc_below(:,j,l) + &
                  LC(isapbelow) * bm_to_litter(:,j,isapbelow,icarbon) * &
                  rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  LC(iheartbelow) * bm_to_litter(:,j,iheartbelow,icarbon) * &
                  rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  LC(iroot) * bm_to_litter(:,j,iroot,icarbon) * &
                  rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  LC(isapbelow)*turnover(:,j,isapbelow,icarbon) * &
                  rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  LC(iheartbelow)*turnover(:,j,iheartbelow,icarbon) * &
                  rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) ) + &
                  LC(iroot)*turnover(:,j,iroot,icarbon) * &
                  rpc(:) * ( EXP( -z_soil(l-1)/rprof(:,j) ) - EXP( -z_soil(l)/rprof(:,j) ) )
            ENDDO
          ENDIF
          !spitfire
          !calculate fuel amount
             fuel_1hr(:,j,k,icarbon) = fuel_1hr(:,j,k,icarbon) + &
                  1.0 * (litterfrac(ileaf,k) * bm_to_litter(:,j,ileaf,icarbon) + &
                  litterfrac(ileaf,k) * turnover(:,j,ileaf,icarbon) + &
                  litterfrac(ifruit,k) * bm_to_litter(:,j,ifruit,icarbon) + &
                  litterfrac(ifruit,k) * turnover(:,j,ifruit,icarbon)) + &
                  0.0450 * (litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
                  litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
                  litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
                  litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
                  litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon) )
             

             fuel_10hr(:,j,k,icarbon) = fuel_10hr(:,j,k,icarbon) + &
                  0.0750 * (litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
                  litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
                  litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
                  litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
                  litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon))
             
             fuel_100hr(:,j,k,icarbon) = fuel_100hr(:,j,k,icarbon) + &
                  0.2100 * (litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
                  litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
                  litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
                  litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
                  litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon))

             fuel_1000hr(:,j,k,icarbon) = fuel_1000hr(:,j,k,icarbon) + &
                  0.6700 * (litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
                  litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
                  litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
                  litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
                  litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon))             
             
             fuel_nlitt_total_pft(:,j,k,icarbon) = fuel_1hr(:,j,k,icarbon) + fuel_10hr(:,j,k,icarbon) + &
                  fuel_100hr(:,j,k,icarbon) + fuel_1000hr(:,j,k,icarbon)
             
          !endspit
    	ENDDO
    ENDDO
    !! 2.2.5 add new litter (struct/met, above/below)

!      WRITE (numout,*) 'litter_inc_above range =', minval(litter_inc_above(:,:,:,:)), ',', maxval(litter_inc_above(:,:,:,:))
!      WRITE (numout,*) 'litter_above range =', minval(litter_above(:,:,:,:)), ',', maxval(litter_above(:,:,:,:))

         litter_above(:,:,:,:) = litter_above(:,:,:,:) + litter_inc_above(:,:,:,:)

         litter_below(:,:,:,:,:) = litter_below(:,:,:,:,:) + litter_inc_below(:,:,:,:,:)

!gmjc for grazing litter
    IF (do_slow) THEN
      DO j=2,nvm 
        !! grazed grassland or natural grassland with wild animal
        IF ((is_grassland_manag(j) .AND. is_grassland_grazed(j)) .OR. &
           ((.NOT. is_tree(j)) .AND. natural(j) .AND. &
             & (.NOT. is_grassland_cut(j)) .AND. (.NOT.is_grassland_grazed(j)))) THEN
          WHERE (litter_above(:,:,j,icarbon) .GE. litter_not_avail(:,:,j) &
             .AND. litter_above(:,:,j,icarbon) .GT. 0.0)
            litter_avail_frac(:,:,j) = (litter_above(:,:,j,icarbon) - litter_not_avail(:,:,j)) & 
                  & / litter_above(:,:,j,icarbon)
          ! if litter not available equal to or larger than litter
          ELSEWHERE 
            litter_avail_frac(:,:,j) = 0.0
          ENDWHERE
!          IF (ANY(litter_avail_frac .LT. 0.0)) THEN
!            WRITE (numout,*) 'frac error',litter_above(:,:,j,icarbon),litter_not_avail(:,:,j),litter_avail_frac(:,:,j)
!            STOP 'error fraction litter available for grazing < 0'
!          ENDIF
        ELSE
          litter_avail_frac(:,:,j) = 1.0
        ENDIF
      ENDDO
    ENDIF
!ENDJCADD
!end gmjc
    !! 2.2.6 for security: can't add more lignin than structural litter (above/below)
!!!SIMON ADDED ORCHIDOC
       DO m = 2,nvm !Lopp over PFTs

          lignin_struc_inc_above(:,m) = &
               MIN( lignin_struc_inc_above(:,m), litter_inc_above(:,istructural,m,icarbon) )

       ENDDO

    DO l = 1, ndeep !Loop over soil levels (below ground)
       DO m = 2,nvm !Lopp over PFTs

          lignin_struc_inc_below(:,m,l) = &
               MIN( lignin_struc_inc_below(:,m,l), litter_inc_below(:,istructural,m,l,icarbon) )

       ENDDO
    ENDDO

    !! 2.2.7 new lignin content: add old lignin and lignin increase, divide by 
    !!       total structural litter (above)

!      WRITE (numout,*) 'lignin_struc_above range =', minval(lignin_struc_above(:,:)), ',', maxval(lignin_struc_above(:,:))
!      WRITE (numout,*) 'old_struc_above range =', minval(old_struc_above(:,:)), ',', maxval(old_struc_above(:,:))
!      WRITE (numout,*) 'lignin_struc_inc_above range =', minval(lignin_struc_inc_above(:,:)), ',', maxval(lignin_struc_inc_above(:,:))


       DO m = 2,nvm !Loop over PFTs
           WHERE( litter_above(:,istructural,m,icarbon) .GT. min_stomate )
 
              lignin_struc_above(:,m) = lignin_struc_above(:,m) * old_struc_above(:,m)
              lignin_struc_above(:,m) = lignin_struc_above(:,m) + lignin_struc_inc_above(:,m)
              lignin_struc_above(:,m) = lignin_struc_above(:,m) / litter_above(:,istructural,m,icarbon)
           ELSEWHERE
              lignin_struc_above(:,m) = zero
	   ENDWHERE
       END DO
       
       
    !! 2.2.7.2 new lignin content: add old lignin and lignin increase, divide by 
    !!       total structural litter (below)
    DO l = 1, ndeep !Loop over soil levels (below ground)
       DO m = 2,nvm !Loop over PFTs
          WHERE( litter_below(:,istructural,m,l,icarbon) .GT. min_stomate )
 
             lignin_struc_below(:,m,l) = lignin_struc_below(:,m,l) * old_struc_below(:,m,l)
             lignin_struc_below(:,m,l) = lignin_struc_below(:,m,l) + lignin_struc_inc_below(:,m,l)
             lignin_struc_below(:,m,l) = lignin_struc_below(:,m,l) /litter_below(:,istructural,m,l,icarbon)
          ELSEWHERE
             lignin_struc_below(:,m,l) = zero
          ENDWHERE
       ENDDO
    ENDDO
!!!!SIMON END ADDITION
    
    !! 2.3 new litter fraction per PFT (for structural and metabolic litter, above
    !!       the ground).
!!!!SIMON ADD ORCHIDOC BEGIN
    DO j = 1,nvm !Loop over PFTs
       DO l =1,nlitt  
         WHERE ( litter_above(:,l,j,icarbon) .GT. min_stomate )

          litterpart(:,j,l) = &
               ( litter_pft(:,j,l,icarbon) + litter_inc_PFT_above(:,j,l,icarbon) ) / litter_above(:,l,j,icarbon)

         ELSEWHERE

          litterpart(:,j,l) = zero

         ENDWHERE
     	ENDDO
     ENDDO

!!!!SIMON ADD ORCHIDOC END
 
  !! 3. Temperature control on decay: Factor between 0 and 1

         
    !! 3.2 below: convolution of temperature and decomposer profiles
    !!            (exponential decomposer profile supposed)
   
!!rpc is a remnant from MICT
    !! 3.2.1 rpc is an integration constant such that the integral of the root profile is 1.
    rpc(:) = un / ( un - EXP( -z_soil(nbdl) / z_decomp ) )

!!	SIMON Not Sure if to keep this merge in from ORCHIDOC??
!    DO j=1,nlitt
!       control_temp_above(:,j) = control_temp_func (npts, tsurf,litter_tau(j)*(un+poor_soils(:))) 
!    ENDDO         
!!Uncertainty   
!    tsoil_decomp(:) = zero
!
!!! Commented below = merge v1 
!
!   tsoil_decomp(:) = tsurf(:,1)

!    tsoil_decomp = tsurf
! 	write (numout,*) "SIMON NIGHTMARE 1018"
!	write (numout,*) "tsoil_decomp: ",tsoil_decomp 
!	write (numout,*) "tsurf: ",tsurf
!Merge v2 is taking directly from ORCHIDOC
!    DO l = 1, nbdl
!       DO j = 1,npool
!
!          tsoil_decomp(:) = tsoil(:,l) 
!
 !         control_temp_below(:,l,j) = control_temp_func (npts,tsoil_decomp,pool_tau(j))
!
!       ENDDO
!    ENDDO
!!!!SIMON Merge FROM ORCHIDOC
    !! 3.2.1 integrate over the nbdl levels
!!	
    tsoil_decomp(:) = zero
!	write (numout,*) "temp_in: ",tsoil_decomp 
!!!SIMON merge v2 - use frozen_respiration_func; merge v3 THROW in DO for vegetation - replace tsoil with tprof
!! 	 DO l=1, nbdl
!! 	       DO j = 1,npool
!!	       	 DO m = 1,nvm
!! 
!! 		tsoil_decomp(:) = tsoil(:,l)
!! 
!!     	control_temp_below(:,l,npool+j,m) = control_temp_func (npts,tsoil_decomp,frozen_respiration_func)
!! 	
!! 	 	ENDDO
!!	    ENDDO
!! 	ENDDO

!     !! 3.1 above: surface temperature  
     DO j=1,nlitt
        control_temp_above(:,j) = control_temp_func (npts,tsurf,frozen_respiration_func) 
     ENDDO         
! write (numout,*) "control_temp_above min/max=",  minval(control_temp_above), "/", maxval(control_temp_above) 
!!!SIMON merge v3 - use frozen_respiration_func; merge v3 THROW in ndeep/ DO for vegetation/ - replace tsoil with tprof
!
! 	 DO l=1, ndeep
! 	       DO j = 1,npool
!	       	 DO m = 1,nvm
! 
! 		tsoil_decomp(:) = tprof(:,l,m)
! 
!     	control_temp_below(:,l,npool+j,m) =  microactem_DOC( temp, frozen_respiration_func, moist_in, i_ind, j_ind, k_ind, is_doc)  
!	!!!SIMON replaced original func with microactem_DOC for all carbon pools::: control_temp_func !(npts,tsoil_decomp,frozen_respiration_func)
! 	
! 	 	ENDDO
!	    ENDDO
! 	ENDDO

!!!! crops

    ! for STICS
    ! 3.3  calculation of soil temperature with the resolution of 1 cm
    !      here, we calculated the soil temperature with 1 cm for three layers around sowing depth, see STICS code
   
    ! initialization of the tsoil_cm
    
    tsoil_cm(:, :, :) = zero
    ldep(:, :) = zero    ! different for different PFTs
    ! the depths of three layers around sowing depth, in cm and they are transformed into integer

    DO ipft = 2, nvm
       IF (ok_LAIdev(ipft)) THEN 
          ldep(ipft, :) = (/SP_profsem(ipft) - 1.0, SP_profsem(ipft), SP_profsem(ipft) + 1.0/) !three depths,  SP_profsem is in cma
          !!! 3cm by default
       ENDIF
    ENDDO    
    
    IF (printlev>=4) THEN
        WRITE(*,*) 'three layer depth in litter is', ldep(13, :)
        WRITE(*,*) 'z_soil in litter is', z_soil
    ENDIF
    ! loop for each layer of the three layers and calculate the soil temperature at the specific depth

    
    DO ipft = 2, nvm 
       IF (ok_LAIdev(ipft)) THEN
  
          DO il = 1, SIZE(ldep, 2)! loop for the three layers, three depth
             
             ! initialize the surface soil depth, that means 0 cm
              uldep = z_soil(0)*100.0   ! the upper limit of the first layer, and also the initial depth
              bldep = z_soil(1)/2.0*100.0 ! the lower limit of the first half layer, and also the initial depth            
             ! initialize the surface soil temperature
             DO nhl = 1, 2*nbdl
                ultsoil(:, nhl) = tsurf(:) ! the surface soil temperature and also the initial soil temperature     
             ENDDO
 
             DO nhl = 1, 2*nbdl
               IF ((ldep(ipft, il) .GE. uldep) .AND. (ldep(ipft, il) .LT. bldep)) THEN !
                  IF (nhl < 2*nbdl) THEN
                     tsoil_cm(:,ipft, il) = &
                         &  ultsoil(:,nhl) + & 
                         &  ((tsoil(:,  nhl - FLOOR((nhl-1.0)/2.0)) + tsoil(:, NINT(nhl/2.0)))/2.0 - ultsoil(:, nhl))&
                         &  /(bldep - uldep)&
                         &  *(ldep(ipft, il) - uldep)
                     ! linear interpolation
                  ELSE
                     tsoil_cm(:, ipft, il) = tsoil(:, nbdl) 
                  ENDIF
               ENDIF

               uldep = bldep 
               bldep = bldep + (z_soil(CEILING(nhl/2.0))*100.0 - z_soil(CEILING(nhl/2.0)-1)*100.0)/2.0
               IF (nhl < 2*nbdl) THEN
                  ultsoil(:, nhl) =(tsoil(:, nhl - FLOOR((nhl-1.0)/2.0)) + tsoil(:, NINT(nhl/2.0)))/2.0  ! 
               ELSE 
                  ultsoil(:, nhl) = tsoil(:, nbdl)
               ENDIF
             ENDDO ! nhl
          ENDDO ! il
       ENDIF
    ENDDO ! ipft
    
    
!!!! end crops, xuhui

  !! 4. Moisture control. Factor between 0 and 1
    
    !! 4.1 above the ground: litter humidity
!    control_moist(:,iabove) = control_moist_func (npts, litterhum)
!!!!SIMON ADDED FROM ORCHIDOC

		one_array(:) = un
	    soilhum_decomp(:) = zero
    	DO m= 1,nvm
           soilhum_decomp(:) =soil_mc(:,1,pref_soil_veg(m))*(z_soil(1)/z_soil(4)) + &
                            soil_mc(:,2,pref_soil_veg(m))*((z_soil(2)-z_soil(1))/z_soil(4)) + &
                            soil_mc(:,3,pref_soil_veg(m))*((z_soil(3)-z_soil(2))/z_soil(4)) + &
                            soil_mc(:,4,pref_soil_veg(m))*((z_soil(4)-z_soil(3))/z_soil(4))
         !
!	 soilhum_decomp(:)=0.3
! write (numout,*) "soilhum_decomp min/max=",  minval(soilhum_decomp), "/", maxval(soilhum_decomp) 
           IF (moist_func_Moyano) THEN
        control_moist_above(:,m) = control_moist_func_moyano (npts, soilhum_decomp, zz_coef_deep, bulk_dens, &
                                                    clay, carbon_32l, veget_max)
       ELSE 
         control_moist_above(:,m) = control_moist_func (npts, soilhum_decomp)
       ENDIF
! write (numout,*) "control_moist_above(:,m) min/max=",  minval(control_moist_above(:,m)), "/", maxval(control_moist_above(:,m)) 
 
    ENDDO

    !    control_moist_above(:,m) = control_moist_func (npts, soilhum_decomp)
	!	ENDDO
    !
    !! 4.2 below: convolution of humidity and decomposer profiles
    !            (exponential decomposer profile supposed)

    !! 4.2.1 rpc is an integration constant such that the integral of the root profile is 1.
    rpc(:) = un / ( un - EXP( -z_soil(nbdl) / z_decomp ) )

   
    !! 4.2.2 integrate over the nbdl levels
    soilhum_decomp(:) = zero
!!SIMON ADDED ORCHIDOC
!!NOTE !!! There is the nvm loop before which maybe should be excluded
    DO l = 1, ndeep !Loop over soil levels
      DO m =1,nvm
!!!SIMON REMEMBER TO RETURN soilhum_decomp = soil_mc		        
!		soilhum_decomp(:) = soil_mc_32l(:,l,pref_soil_veg(m))
!         IF (moist_func_Moyano) THEN
!            control_moist_below(:,l,m) = control_moist_func_moyano (npts, soilhum_decomp, zz_coef_deep, bulk_dens, &
!                 clay, carbon_32l, veget_max)
 !        ELSE
 !           control_moist_below(:,l,m) = microactem_DOC( temp, frozen_respiration_func, moist_in, i_ind, j_ind, k_ind, is_doc)!!!control_moist_func !(npts, soilhum_decomp)
!         ENDIF
	  END DO
	ENDDO
!SIMON REMOVAL FOR ORCHIDOC


!    DO l = 1, nbdl !Loop over soil levels
!
!       soilhum_decomp(:) = &
!            soilhum_decomp(:) + soilhum(:,l) * rpc(:) * &
!            ( EXP( -z_soil(l-1)/z_decomp ) - EXP( -z_soil(l)/z_decomp ) )
!
!    ENDDO
!
!    control_moist(:,ibelow) = control_moist_func (npts, soilhum_decomp)
!!!!! crops

    ! 4.3 calculation of soil relative humidity of three depths
    ! similar to the calculation of soil temperature, see above
    
    ! initialize the soil humidity for the three layers
 
    soilhum_cm(:, :, :) = zero
    ldep(:, :) = zero
  

    ! the depths for the three layers around the sowing depth

    DO ipft = 1, nvm
       IF (ok_LAIdev(ipft)) THEN 
          ldep(ipft, :) = (/SP_profsem(ipft) - 1.0, SP_profsem(ipft), SP_profsem(ipft) + 1.0/) !three depths,  SP_profsem is in cm
       ENDIF
    ENDDO    
   
!    IF (printlev>=4) WRITE(*,*) 'in stomate_litter, the ldep of wheat is', ldep(12, :) 

 
    ! loop calculation 

    DO ipft = 1, nvm
       IF (ok_LAIdev(ipft)) THEN
         DO il = 1, SIZE(ldep, 2)!the ith layer 

            ! initialize the surface depths, this variable can be changed for reassign a value for the upper limit depth for the ith half layer
            !uldep(:) = z_soil(1)*100.0   ! the upper limit of the first layer, and also the initial depth

            uldep = z_soil(0)*100.0   ! the upper limit of the first layer, and also the initial depth
            bldep = z_soil(1)/2.0*100.0
 
            ! initialize the surface soil moisture, is it correct?
            DO nhl = 1, 2*nbdl
               ulhum(:, nhl) = soilhum(:, 1) ! the surface soil moisture and also the initial soil moisture     
            ENDDO

            DO nhl = 1, 2*nbdl
              IF ((ldep(ipft, il) .GE. uldep) .AND. (ldep(ipft,il) .LT. bldep)) THEN 
                  IF (nhl < 2*nbdl) THEN
                     soilhum_cm(:, ipft, il) = &
                         &  ulhum(:, nhl) + & 
                         &  ((soilhum(:, nhl - FLOOR((nhl-1)/2.0)) + soilhum(:, NINT(nhl/2.0)))/2.0 - ulhum(:, nhl))&
                         &  /(bldep - uldep)&
                         &  *(ldep(ipft, il) - uldep)
                     ! linear interpolation
                  ELSE
                     soilhum_cm(:, ipft, il) = soilhum(:, nbdl) 
                  ENDIF
              ENDIF

              uldep = bldep   
              bldep = bldep + (z_soil(CEILING(nhl/2.0))*100.0 - z_soil(CEILING(nhl/2.0)-1)*100.0)/2.0
              IF (nhl < 2*nbdl) THEN
                 ulhum(:, nhl) =(soilhum(:, nhl - FLOOR((nhl-1.0)/2.0)) + soilhum(:, NINT(nhl/2.0)))/2.0  ! 
              ELSE
                 ulhum(:, nhl) = soilhum(:, nbdl)
              ENDIF
            ENDDO ! nhl
         ENDDO ! il
      ENDIF    
    ENDDO !ipft
!!!!! end crops, xuhui

  !! 5. fluxes from litter to carbon pools and respiration

    


      DO m =1,nvm
          !spitfire
          !update the fuel poop size accordingly after respiration
          qd_fuel(:,:)=qd(:,:)

             DO k=1, npts
               IF (fuel_nlitt_total_pft(k,m,istructural,icarbon).GT.min_stomate .AND. qd_fuel(k,icarbon).GT.min_stomate) THEN
                
                fuel_1hr(k,m,istructural,icarbon) = fuel_1hr(k,m,istructural,icarbon) - (qd_fuel(k,icarbon) * &    
                     fuel_1hr(k,m,istructural,icarbon)/fuel_nlitt_total_pft(k,m,istructural,icarbon))
                
                fuel_10hr(k,m,istructural,icarbon) = fuel_10hr(k,m,istructural,icarbon) - (qd_fuel(k,icarbon) * &    
                     fuel_10hr(k,m,istructural,icarbon)/fuel_nlitt_total_pft(k,m,istructural,icarbon))
                
                fuel_100hr(k,m,istructural,icarbon) = fuel_100hr(k,m,istructural,icarbon) - (qd_fuel(k,icarbon) * &    
                     fuel_100hr(k,m,istructural,icarbon)/fuel_nlitt_total_pft(k,m,istructural,icarbon))
                
                fuel_1000hr(k,m,istructural,icarbon) = fuel_1000hr(k,m,istructural,icarbon) - (qd_fuel(k,icarbon) * &
                     fuel_1000hr(k,m,istructural,icarbon)/fuel_nlitt_total_pft(k,m,istructural,icarbon))
                
                fuel_nlitt_total_pft(k,m,istructural,icarbon) = fuel_1hr(k,m,istructural,icarbon) + &
                     fuel_10hr(k,m,istructural,icarbon) + fuel_100hr(k,m,istructural,icarbon) + & 
                     fuel_1000hr(k,m,istructural,icarbon)
               ENDIF

               diff_frac(k) = litter_above(k,istructural,m,icarbon) - fuel_nlitt_total_pft(k,m,istructural,icarbon)

               IF (diff_frac(k).GT.min_stomate .OR. -1.0*diff_frac(k).GT.min_stomate) THEN
                   ! simply divided even fraction to each fuel class, that is 1/4 of buffer
                   fuel_1hr(k,m,istructural,icarbon) = fuel_1hr(k,m,istructural,icarbon) + 0.25 * diff_frac(k)
                   fuel_10hr(k,m,istructural,icarbon) = fuel_10hr(k,m,istructural,icarbon) + 0.25 * diff_frac(k)
                   fuel_100hr(k,m,istructural,icarbon) = fuel_100hr(k,m,istructural,icarbon) + 0.25 * diff_frac(k)
                   fuel_1000hr(k,m,istructural,icarbon) = fuel_1000hr(k,m,istructural,icarbon) + 0.25 * diff_frac(k)
                   fuel_nlitt_total_pft(k,m,istructural,icarbon) = fuel_1hr(k,m,istructural,icarbon) + &
                        fuel_10hr(k,m,istructural,icarbon) + fuel_100hr(k,m,istructural,icarbon) + & 
                        fuel_1000hr(k,m,istructural,icarbon)
               ENDIF
             ENDDO
	  END DO
#ifdef STRICT_CHECK
             ! Check consistency in fuel_Xhr variables. Negative values are not allowed
!             IF (ANY(fuel_1hr < 0)) CALL ipslerr_p(3, 'stomate_litter', 'fuel_1hr has negative values', '', '')  
!             IF (ANY(fuel_10hr < 0)) CALL ipslerr_p(3, 'stomate_litter', 'fuel_10hr has negative values', '', '')  
!             IF (ANY(fuel_100hr < 0)) CALL ipslerr_p(3, 'stomate_litter', 'fuel_100hr has negative values', '', '')  
!             IF (ANY(fuel_1000hr < 0)) CALL ipslerr_p(3, 'stomate_litter', 'fuel_1000hr has negative values', '', '')  
#endif
    
          !endspit

!!!SIMON  HERE I COMMENT OUT MICT VERSION OF ABOVE STRUCTURAL AND METABOLIC LITTER DECOMPOSITION
!!!DIRECT BLOC FROM ORCHIDOC
!  
       DO m = 2,nvm !Loop over PFTs
!!ABOVE LITTER STRUC !!ABOVE LITTER STRUC !!ABOVE LITTER STRUC !!ABOVE LITTER STRUC
	WHERE (soil_mc(:,1,pref_soil_veg(m)) .GT. zero)
          fd(:) = dt/(litter_tau(istructural)*(un+poor_soils(:))) * &
!!SIMON: CHECK calc of vars below this line
             control_temp_above(:,istructural) * control_moist_above(:,m) * exp( -litter_struct_coef * lignin_struc_above(:,m) )
!
	ELSEWHERE
          fd(:) = zero
          fd_flood(:) = zero
      ENDWHERE

!!	WRITE (numout,*) 'L1490 LAb_st soil_mc =', soil_mc(:,1,pref_soil_veg(m))
!	WRITE (numout,*) 'L1490 LAb_st poor_soils(:) =', poor_soils(:)
!	WRITE (numout,*) 'L1490 LAb_st control_temp_above(:,istructural) =', control_temp_above(:,istructural)
!	 WRITE (numout,*) 'L1490 LAb_st control_moist_above(:,m) =', control_moist_above(:,m)
!	 WRITE (numout,*) 'L1490 LAb_st lignin_struc_above(:,m) =', lignin_struc_above(:,m)
!
	DO k = 1,nelements
              qd(:,k) = litter_above(:,istructural,m,k) * fbact_str(:,1,m) * (un - flood_frac)
              qd_flood(:,k) = litter_above(:,istructural,m,k) * fbact_str(:,1,m) * flood_frac/trois
!!Commented to test fbact instead of fd
!!             qd(:,k) = litter_above(:,istructural,m,k) * fd(:) * (un - flood_frac)
!!             qd_flood(:,k) = litter_above(:,istructural,m,k) * fd(:) * flood_frac/trois
          ENDDO

!      WRITE (numout,*) 'L1495 LAb_st qd after qd calc range =', minval(qd(:,icarbon)), ',', maxval(qd(:,icarbon))
!      WRITE (numout,*) 'L1495 LAb_st qd_flood after qd flood calc range =', minval(qd_flood(:,icarbon)), ',', maxval(qd_flood(:,icarbon))


          !! 5.1.2 decompose same fraction of structural part of dead leaves. Not exact
          !!       as lignine content is not the same as that of the total structural litter.
          dead_leaves(:,m,istructural) = dead_leaves(:,m,istructural) * (un - fd(:)*(un - flood_frac(:)) - fd(:)*flood_frac(:)/trois)

      !BE CAREFUL: Here resp_hetero_litter is divided by dt to have a value which corresponds to
      ! the sechiba time step but then in stomate.f90 resp_hetero_litter is multiplied by dt.
      ! Perhaps it could be simplified. Moreover, we must totally adapt the routines to the dtradia/one_day
      ! time step and avoid some constructions that could create bug during future developments.

!      WRITE (numout,*) 'L1509 LAb_st frac_soil(istructural,iactive,iabove) =', frac_soil(istructural,iactive,iabove)
! IF (maxval(resp_hetero_litter(:,m,iabove)) .GT. zero)   WRITE (numout,*) 'L1509 Whenresp_hetero_litter LAb_st GT 0, &
! LAb_st lignin_struc_above(:,m) range =', minval(lignin_struc_above(:,m)), ',', maxval(lignin_struc_above(:,m))
!
!     IF (maxval(resp_hetero_litter(:,m,iabove)) .GT. zero)  WRITE (numout,*) 'L1509 LAb_st resp_hetero_litter(:,m,iabove) GT zero range =', &
!      minval(resp_hetero_litter(:,m,iabove)), ',', maxval(resp_hetero_litter(:,m,iabove))

!!!COMMENT: SIMON == why is this calculated twice?      
          resp_hetero_litter(:,m,iabove) = resp_hetero_litter(:,m,iabove) + &
               ( 1. - frac_soil(istructural,iactive,iabove) ) * qd(:,icarbon) * ( 1. - lignin_struc_above(:,m) ) / dt
          resp_hetero_flood(:,m) = resp_hetero_flood(:,m) + &
               ( 1. - frac_soil(istructural,iactive,iabove) ) * qd_flood(:,icarbon) *( 1. - lignin_struc_above(:,m) ) / dt
!!!HET_RESP WRITE 1:                              
!IF (maxval(resp_hetero_litter(:,m,iabove)) .GT. zero) THEN
! WRITE (numout,*) 'L1528 LAb_st frac_soil(istructural,iactive,iabove)=', frac_soil(istructural,iactive,iabove)
!      WRITE (numout,*) 'L1528 LAb_st resp_hetero_litter(:,m,iabove) range =', minval(resp_hetero_litter(:,m,iabove)), ',', maxval(resp_hetero_litter(:,m,iabove))
!ENDIF
          resp_hetero_litter(:,m,iabove) = resp_hetero_litter(:,m,iabove) + &
               ( 1. - frac_soil(istructural,islow,iabove) ) * qd(:,icarbon) * lignin_struc_above(:,m) / dt
          resp_hetero_flood(:,m) = resp_hetero_flood(:,m) + &
               ( 1. - frac_soil(istructural,islow,iabove) ) * qd_flood(:,icarbon) * lignin_struc_above(:,m) / dt
!!!HET_RESP WRITE 2:                              
!IF (maxval(resp_hetero_litter(:,m,iabove)) .GT. zero) THEN
!      WRITE (numout,*) 'L1539 LAb_st resp_hetero_litter(:,m,iabove) range =', minval(resp_hetero_litter(:,m,iabove)), ',', maxval(resp_hetero_litter(:,m,iabove))
! WRITE (numout,*) 'L1539 LAb_st frac_soil(istructural,islow,iabove)=', frac_soil(istructural,islow,iabove)
!END IF
  !! 5.1.3 Calculation of the soilcarbon_input in gC m^-2 of water
				
		DO k = 1, nelements

             soilcarbon_input_DOC(:,m,1,istrabo,k) = (frac_soil(istructural,iactive,iabove) * ( 1. - lignin_struc_above(:,m) ) * qd(:,k) + &
                                  frac_soil(istructural,islow,iabove) *  qd(:,k) * lignin_struc_above(:,m) ) /dt 
             floodcarbon_input(:,m,iact,k) = frac_soil(istructural,iactive,iabove) * ( 1. - lignin_struc_above(:,m) ) * qd_flood(:,k) / dt
             floodcarbon_input(:,m,islo,k) = frac_soil(istructural,islow,iabove) * qd_flood(:,k) * lignin_struc_above(:,m) /dt
		ENDDO

          litter_above(:,istructural,m,:) = litter_above(:,istructural,m,:) - qd(:,:) - qd_flood(:,:)


!write (numout,*) "L1535 litter_above struc max/min =", maxval(litter_above(:,istructural,m,:)), "/", minval(litter_above(:,istructural,m,:))

!write (numout,*) 'SIMON NIGHTMARE 1191'
!!END ABOVE LITTER STRUC !!END ABOVE LITTER STRUC !! END ABOVE LITTER STRUC !!END ABOVE LITTER STRUC
	       
!!ABOVE METAB LITTER !!ABOVE METAB LITTER !!ABOVE METAB LITTER !!ABOVE METAB LITTER
          !! 5.2 above ground metabolic litter goes into active carbon pool + respiration
         
          !! 5.2.1 total quantity of aboveground metabolic litter that is decomposed

      WHERE (soil_mc(:,1,pref_soil_veg(m)) .GT. zero)
          fd(:) = dt/(litter_tau(imetabolic)*(un+poor_soils(:))) * control_temp_above(:,imetabolic) * control_moist_above(:,m)
      ELSEWHERE
          fd(:) = zero
      ENDWHERE
!
!	WRITE (numout,*) 'L1570 LAb_met soil_mc =', soil_mc(:,1,pref_soil_veg(m))
!	WRITE (numout,*) 'L1570 LAb_met poor_soils(:) =', poor_soils(:)
!	WRITE (numout,*) 'L1570 LAb_met control_temp_above(:,istructural) =', control_temp_above(:,istructural)
!	WRITE (numout,*) 'L1570 LAb_met control_moist_above(:,m) =', control_moist_above(:,m)
!	WRITE (numout,*) 'L1570 LAb_met lignin_struc_above(:,m) =', lignin_struc_above(:,m)

          DO k = 1,nelements          
             qd(:,k) = litter_above(:,imetabolic,m,k) * fd(:) * (un - flood_frac)
             qd_flood(:,k) = litter_above(:,imetabolic,m,k) * fd(:) * flood_frac/trois
          ENDDO

!WRITE (numout,*) 'L1581 LAb_met qd after qd calc range =', minval(qd(:,icarbon)), ',', maxval(qd(:,icarbon))
!WRITE (numout,*) 'L1581 LAb_met qd_flood after qd flood calc range =', minval(qd_flood(:,icarbon)), ',', maxval(qd_flood(:,icarbon))

		
          !! 5.2.2 decompose same fraction of metabolic part of dead leaves.
          dead_leaves(:,m,imetabolic) = dead_leaves(:,m,imetabolic) * (un - fd(:)*(un - flood_frac(:)) - fd(:)*flood_frac(:)/trois)

!IF (maxval(resp_hetero_litter(:,m,iabove)) .GT. zero) THEN
!      WRITE (numout,*) 'L1589  LAb_met resp_hetero_litter GT0 frac_soil(istructural,iactive,iabove) =', frac_soil(istructural,iactive,iabove)
!      WRITE (numout,*) 'L1589 LAb_met resp_hetero_litter GT0 lignin_struc_above(:,m) range =', minval(lignin_struc_above(:,m)), ',', maxval(lignin_struc_above(:,m))
!      WRITE (numout,*) 'L1589 LAb_met resp_hetero_litter(:,m,iabove) range =', minval(resp_hetero_litter(:,m,iabove)), ',', maxval(resp_hetero_litter(:,m,iabove))
!ENDIF 
      !BE CAREFUL: Here resp_hetero_litter is divided by dt to have a value which corresponds to
      ! the sechiba time step but then in stomate.f90 resp_hetero_litter is multiplied by dt.
      ! Perhaps it could be simplified. Moreover, we must totally adapt the routines to the dtradia/one_day
      ! time step and avoid some constructions that could create bug during future developments.
          resp_hetero_litter(:,m,iabove) = resp_hetero_litter(:,m,iabove) + &
               ( 1. - frac_soil(imetabolic,iactive,iabove) ) * qd(:,icarbon) / dt
          resp_hetero_flood(:,m) = resp_hetero_flood(:,m) + &
               ( 1. - frac_soil(imetabolic,iactive,iabove) ) * qd_flood(:,icarbon) / dt

!IF (maxval(resp_hetero_litter(:,m,iabove)) .GT. zero) THEN
!     WRITE (numout,*) 'L1603 LAb_met resp_hetero_litter GT0 resp_hetero_litter(:,m,iabove) range =', minval(resp_hetero_litter(:,m,iabove)), ',', maxval(resp_hetero_litter(:,m,iabove))
!      WRITE (numout,*) 'L1603 LAb_met resp_hetero_litter GT0 frac_soil(imetabolic,iactive,iabove)=', frac_soil(imetabolic,iactive,iabove)
!ENDIF
          !! 5.2.3 Calculation of the soilcarbon_input in gC m^-2 of water
             ! For above ground litter we assume that the soilcarbon_input coming from AB
             ! litter decomposition is directly incorporated into the 1st soil
             ! layers

        DO k = 1, nelements
             soilcarbon_input_DOC(:,m,1,imetabo,k) = frac_soil(imetabolic,iactive,iabove) *  qd(:,k) / dt              
             floodcarbon_input(:,m,iact,k) = floodcarbon_input(:,m,iact,k) + frac_soil(imetabolic,iactive,iabove) *  qd_flood(:,k) / dt
         ENDDO
    		
          litter_above(:,imetabolic,m,:) = litter_above(:,imetabolic,m,:) - qd(:,:) - qd_flood(:,:)
     ENDDO   
!SIMON COMMENTED THIS ANNOYING CRASH THRESHOLD          
!IF (maxval(litter_above) .GT. 1000) CALL ipslerr_p(3, 'stomate_litter', 'litter_above above 1000', '', '') !write (numout, *) "ACHTUNG" 

!!ORCHIDOC END MICT BELOW
     DO m =1,nvm
          !spitfire
          !update aboveground fuel load
          qd_fuel(:,:) = qd(:,:)


             DO k=1, npts
               IF (fuel_nlitt_total_pft(k,m,imetabolic,icarbon).gt.min_stomate .and. qd_fuel(k,icarbon).gt.min_stomate) THEN
                fuel_1hr(k,m,imetabolic,icarbon) = fuel_1hr(k,m,imetabolic,icarbon) - (qd_fuel(k,icarbon) * &
                     fuel_1hr(k,m,imetabolic,icarbon)/fuel_nlitt_total_pft(k,m,imetabolic,icarbon))
                
                fuel_10hr(k,m,imetabolic,icarbon) = fuel_10hr(k,m,imetabolic,icarbon) - (qd_fuel(k,icarbon) * &
                     fuel_10hr(k,m,imetabolic,icarbon)/fuel_nlitt_total_pft(k,m,imetabolic,icarbon))
                
                fuel_100hr(k,m,imetabolic,icarbon) = fuel_100hr(k,m,imetabolic,icarbon) - (qd_fuel(k,icarbon) * &
                     fuel_100hr(k,m,imetabolic,icarbon)/fuel_nlitt_total_pft(k,m,imetabolic,icarbon))
                
                fuel_1000hr(k,m,imetabolic,icarbon) = fuel_1000hr(k,m,imetabolic,icarbon) - (qd_fuel(k,icarbon) * &
                     fuel_1000hr(k,m,imetabolic,icarbon)/fuel_nlitt_total_pft(k,m,imetabolic,icarbon))
                
                fuel_nlitt_total_pft(k,m,imetabolic,icarbon) = fuel_1hr(k,m,imetabolic,icarbon) + &
                     fuel_10hr(k,m,imetabolic,icarbon) + fuel_100hr(k,m,imetabolic,icarbon) + &
                     fuel_1000hr(k,m,imetabolic,icarbon)
               ENDIF

               diff_frac(k) = litter_above(k,imetabolic,m,icarbon) - fuel_nlitt_total_pft(k,m,imetabolic,icarbon)

               IF(diff_frac(k).GT.min_stomate .OR. -1.0*diff_frac(k).GT.min_stomate) THEN
                   ! simply divided even fraction to each fuel class, that is 1/4 of buffer
                   fuel_1hr(k,m,imetabolic,icarbon) = fuel_1hr(k,m,imetabolic,icarbon) + 0.25 * diff_frac(k)
                   fuel_10hr(k,m,imetabolic,icarbon) = fuel_10hr(k,m,imetabolic,icarbon) + 0.25 * diff_frac(k)
                   fuel_100hr(k,m,imetabolic,icarbon) = fuel_100hr(k,m,imetabolic,icarbon) + 0.25 * diff_frac(k)
                   fuel_1000hr(k,m,imetabolic,icarbon) = fuel_1000hr(k,m,imetabolic,icarbon) + 0.25 * diff_frac(k)
                   fuel_nlitt_total_pft(k,m,imetabolic,icarbon) = fuel_1hr(k,m,imetabolic,icarbon) + &
                        fuel_10hr(k,m,imetabolic,icarbon) + fuel_100hr(k,m,imetabolic,icarbon) + &
                        fuel_1000hr(k,m,imetabolic,icarbon)
               ENDIF
             ENDDO
        ENDDO
#ifdef STRICT_CHECK
             ! Check consistency in fuel_Xhr variables. Negative values are not allowed
!             IF (ANY(fuel_1hr < 0)) CALL ipslerr_p(3, 'stomate_litter', 'fuel_1hr has negative values', '', '')  
!             IF (ANY(fuel_10hr < 0)) CALL ipslerr_p(3, 'stomate_litter', 'fuel_10hr has negative values', '', '')  
!             IF (ANY(fuel_100hr < 0)) CALL ipslerr_p(3, 'stomate_litter', 'fuel_100hr has negative values', '', '')  
!             IF (ANY(fuel_1000hr < 0)) CALL ipslerr_p(3, 'stomate_litter', 'fuel_1000hr has negative values', '', '')  
#endif

          !endspit

	DO l = 1,ndeep
       DO m = 1,nvm !Loop over PFTs
!
!!!
!	WRITE (numout, *) "SIMON NIGHTMARE LINE 1323" 
!
!
!
          !! 6.1 structural litter: goes into active and slow carbon pools respiration

          !! 6.1.1 total quantity of below ground structural litter which is decomposed
!    WHERE (soil_mc_32l(:,l,pref_soil_veg(m)) .GT. zero)
!           
!	     
!	     fd(:) = dt/(litter_tau(istructural)*(un+poor_soils(:))) * &
!               control_temp_below(:,l,istrbel,m) * control_moist_below(:,l,m) * exp(-litter_struct_coef * lignin_struc_below(:,m,l) )
!    ELSEWHERE
!          fd(:) = zero
!    ENDWHERE
!
          DO k = 1,nelements
             qd(:,k) = litter_below(:,istructural,m,l,k) * fbact_str(:,l,m) * (un - flood_frac)
             qd_flood(:,k) = litter_below(:,istructural,m,l,k) * fbact_str(:,l,m) * flood_frac/trois
          ENDDO          
          

      !BE CAREFUL: Here resp_hetero_litter is divided by dt to have a value which corresponds to
      ! the sechiba time step but then in stomate.f90 resp_hetero_litter is multiplied by dt.
      ! Perhaps it could be simplified. Moreover, we must totally adapt the routines to the dtradia/one_day
      ! time step and avoid some constructions that could create bug during future developments.
          resp_hetero_litter(:,m,ibelow) = resp_hetero_litter(:,m,ibelow) + &
               ( 1. - frac_soil(istructural,iactive,ibelow) ) * qd(:,icarbon) * &
               ( 1. - lignin_struc_below(:,m,l) ) / dt
          resp_hetero_flood(:,m) = resp_hetero_flood(:,m) + &
               ( 1. - frac_soil(istructural,iactive,ibelow) ) * qd_flood(:,icarbon) * &
               ( 1. - lignin_struc_below(:,m,l) ) / dt


      !BE CAREFUL: Here resp_hetero_litter is divided by dt to have a value which corresponds to
      ! the sechiba time step but then in stomate.f90 resp_hetero_litter is multiplied by dt.
      ! Perhaps it could be simplified. Moreover, we must totally adapt the routines to the dtradia/one_day
      ! time step and avoid some constructions that could create bug during future developments.
          resp_hetero_litter(:,m,ibelow) = resp_hetero_litter(:,m,ibelow) + &
               ( 1. - frac_soil(istructural,islow,ibelow) ) * qd(:,icarbon) * lignin_struc_below(:,m,l) / dt
          resp_hetero_flood(:,m) = resp_hetero_flood(:,m) + &
               ( 1. - frac_soil(istructural,islow,ibelow) ) * qd_flood(:,icarbon) * lignin_struc_below(:,m,l) / dt

          !! 6.1 Calculation of the soilcarbon_input in gC m^-2
          
!!%%%%%%%%%%%%%%%%%%%%%%
          DO k = 1, nelements
             IF (l .GT. sro_bottom) THEN
                  soilcarbon_input_DOC(:,m,l,istrbel,k) = (frac_soil(istructural,iactive,ibelow) * ( 1. - lignin_struc_below(:,m,l) ) &
                       * (qd(:,k)+qd_flood(:,k)) + & 
                         (frac_soil(istructural,islow,ibelow) * (qd(:,k)+qd_flood(:,k)) * lignin_struc_below(:,m,l) )) / dt
             ELSE
                soilcarbon_input_DOC(:,m,l,istrbel,k) = (frac_soil(istructural,iactive,ibelow) * ( 1. - lignin_struc_below(:,m,l) ) &
                       * (qd(:,k)) + &
                         (frac_soil(istructural,islow,ibelow) * (qd(:,k)) * lignin_struc_below(:,m,l) )) / dt
                floodcarbon_input(:,m,iact,k) = floodcarbon_input(:,m,iact,k) + &
                     frac_soil(istructural,iactive,ibelow) * ( 1. - lignin_struc_below(:,m,l) ) * qd_flood(:,k) /dt
                floodcarbon_input(:,m,islo,k) = floodcarbon_input(:,m,islo,k) + (frac_soil(istructural,islow,ibelow) &
                     * qd_flood(:,k) * lignin_struc_below(:,m,l)) / dt
             ENDIF
         ENDDO

          litter_below(:,istructural,m,l,:) = litter_below(:,istructural,m,l,:) - qd(:,:) - qd_flood(:,:)

          !! 6.2 below ground metabolic litter goes into active carbon pool + respiration

          !! 6.2.1 total quantity of belowground metabolic litter that is decomposed
!    WHERE (soil_mc_32l(:,l,pref_soil_veg(m)) .GT. zero)
!             fd(:) = dt/(litter_tau(imetabolic)*(un+poor_soils(:))) * control_temp_below(:,l,imetbel,m) * control_moist_below(:,l,m)
!      ELSEWHERE
!          fd(:) = zero
!     ENDWHERE

          DO k = 1,nelements
             qd(:,k) = litter_below(:,imetabolic,m,l,k) * fbact_met(:,l,m) * (un-flood_frac(:))
             qd_flood(:,k) = litter_below(:,imetabolic,m,l,k) * fbact_met(:,l,m) * flood_frac(:)/trois
          ENDDO


      !BE CAREFUL: Here resp_hetero_litter is divided by dt to have a value which corresponds to
      ! the sechiba time step but then in stomate.f90 resp_hetero_litter is multiplied by dt.
      ! Perhaps it could be simplified. Moreover, we must totally adapt the routines to the dtradia/one_day
      ! time step and avoid some constructions that could create bug during future developments.
          resp_hetero_litter(:,m,ibelow) = resp_hetero_litter(:,m,ibelow) + &
               ( 1. - frac_soil(imetabolic,iactive,ibelow) ) * qd(:,icarbon) /dt
          resp_hetero_flood(:,m) = resp_hetero_flood(:,m) + &
               ( 1. - frac_soil(imetabolic,iactive,ibelow) ) * qd_flood(:,icarbon) /dt
 
          !! 6.2.3 Calculation of the soilcarbon_input in gC m^-2 of water

          DO k = 1, nelements
             IF (l .GT. sro_bottom) THEN
                soilcarbon_input_DOC(:,m,l,imetbel,k) = frac_soil(imetabolic,iactive,ibelow) * (qd(:,k)+qd_flood(:,k))/ dt 
             ELSE
                soilcarbon_input_DOC(:,m,l,imetbel,k) = frac_soil(imetabolic,iactive,ibelow) * qd(:,k)/ dt
                floodcarbon_input(:,m,iact,k) = floodcarbon_input(:,m,iact,k) + frac_soil(imetabolic,iactive,ibelow) * qd_flood(:,k)/ dt
             ENDIF
         ENDDO
         !
          litter_below(:,imetabolic,m,l,:) = litter_below(:,imetabolic,m,l,:) - qd(:,:) - qd_flood(:,:)
         !
       ENDDO
   ENDDO
!!
!!!
!!!SIMON here comments diffusion part because necessary LEAK partis now done by the litter,DOC,SOC cryoturbation routine in soilcarbon.f90 

DO m =2,nvm

litter_below_old(:,:,m,:,:)=zero
litter_below_old_buffer(:,:,m,:,:)=zero
litter_below_old(:,:,m,:,:)=litter_below(:,:,m,:,:)
litter_above_old(:,:,m,:)=zero
litter_above_old(:,:,m,:)=litter_above(:,:,m,:)
!     DO k = 1, nelements ! Loop over elements
!        DO j = 1,nlitt ! Loop over litter pools!
!
!       litter_flux(:,j,m,1,k) = Dif_coef(:)*dt*ABS(litter_below_old(:,j,m,1,k)/(zf_soil(1))-litter_below_old(:,j,m,2,k)/(zf_soil(2)-zf_soil(1)))/(zf_soil(2)-zf_soil(1))
!       litter_above_flux(:,j,m,k) = Dif_coef(:)*dt*ABS(litter_above(:,j,m,k)/(z_litter*1e-3)-litter_below(:,j,m,1,k)/(z_litter*1e-3-zf_soil(1)))
!           ! BE CAREFUL: Here very important assumption we assume the above ground litter layers to be 10mm thick by default.!
!
!     DO l= 2, ndeep-1 ! Loop over soil layers
!       litter_flux(:,j,m,l,k) = Dif_coef(:)*dt*ABS(litter_below_old(:,j,m,l,k)/(zf_soil(l)-zf_soil(l-1))-litter_below_old(:,j,m,l+1,k)/(zf_soil(l+1)-zf_soil(l)))/(zf_soil(l+1)-zf_soil(l))
!     ENDDO
!       litter_flux_old(:,j,m,:,k) = litter_flux(:,j,m,:,k)
!       litter_above_flux_old(:,j,m,k) = litter_above_flux(:,j,m,k)
!
!!       Below we checked if in case that, in a given layer, you have diffusion in the above and below litters, both fluxes are not higher than the stocks of the given layer.
!          WHERE (litter_above_old(:,j,m,k)/(z_litter*1e-3) .LT. litter_below_old(:,j,m,1,k)/(zf_soil(1)) .AND. &
!                 litter_below_old(:,j,m,2,k)/(zf_soil(2)-zf_soil(1)) .LT. litter_below_old(:,j,m,1,k)/(zf_soil(1)) .AND. &
!                 litter_above_flux_old(:,j,m,k)+litter_flux_old(:,j,m,1,k) .GT. litter_below_old(:,j,m,1,k))
!           litter_above_flux(:,j,m,k) = litter_below_old(:,j,m,1,k)*(litter_above_flux_old(:,j,m,k)/(litter_above_flux_old(:,j,m,k)+litter_flux_old(:,j,m,1,k)))
!           litter_flux(:,j,m,1,k) = litter_below_old(:,j,m,1,k)*(litter_flux_old(:,j,m,1,k)/(litter_above_flux_old(:,j,m,k)+litter_flux_old(:,j,m,1,k)))
!          ELSEWHERE (litter_above_old(:,j,m,k)/(z_litter*1e-3) .GE. litter_below_old(:,j,m,1,k)/(zf_soil(1)) .AND. &
!                     litter_below_old(:,j,m,2,k)/(zf_soil(2)-zf_soil(1)) .LT. litter_below_old(:,j,m,1,k)/(zf_soil(1)) .AND. &
!                     litter_below_old(:,j,m,1,k) + litter_above_flux_old(:,j,m,k) - litter_flux_old(:,j,m,1,k) .LE. min_stomate)
!           litter_above_flux(:,j,m,k) = litter_above_flux_old(:,j,m,k)
!           litter_flux(:,j,m,1,k) = litter_below_old(:,j,m,1,k) + litter_above_flux_old(:,j,m,k)
!          ELSEWHERE (litter_above_old(:,j,m,k)/(z_litter*1e-3) .LT. litter_below_old(:,j,m,1,k)/(zf_soil(1)) .AND. &
!                     litter_below_old(:,j,m,2,k)/(zf_soil(2)-zf_soil(1)) .GE. litter_below_old(:,j,m,1,k)/(zf_soil(1)) .AND. &
!                     litter_below_old(:,j,m,1,k) - litter_above_flux_old(:,j,m,k) + litter_flux_old(:,j,m,1,k) .LE. min_stomate)
!           litter_above_flux(:,j,m,k) = litter_below_old(:,j,m,1,k) + litter_flux_old(:,j,m,1,k) 
!           litter_flux(:,j,m,1,k) = litter_flux_old(:,j,m,1,k)
!          ELSEWHERE
!           litter_above_flux(:,j,m,k) = litter_above_flux_old(:,j,m,k)
!           litter_flux(:,j,m,1,k) = litter_flux_old(:,j,m,1,k)
!          ENDWHERE
!
!         WHERE ((litter_above_old(:,j,m,k)/(z_litter*1e-3) .LT. litter_below_old(:,j,m,1,k)/(zf_soil(1))) .AND. &
!                ((litter_above_flux(:,j,m,k) - litter_below_old(:,j,m,1,k)) .GE. min_stomate))
!           litter_above(:,j,m,k) = litter_above_old(:,j,m,k) + litter_below_old(:,j,m,1,k) 
!           litter_below_old_buffer(:,j,m,1,k) = -litter_below_old(:,j,m,1,k) 
!           litter_below(:,j,m,1,k) = zero
!          ELSEWHERE ((litter_above_old(:,j,m,k)/(z_litter*1e-3) .LT. litter_below_old(:,j,m,1,k)/(zf_soil(1))) .AND. &
!                 ((litter_below_old(:,j,m,1,k) - litter_above_flux(:,j,m,k)) .GT. min_stomate))
!           litter_above(:,j,m,k) = litter_above_old(:,j,m,k) + litter_above_flux(:,j,m,k) 
!           litter_below_old_buffer(:,j,m,1,k) =  - litter_above_flux(:,j,m,k)
!           litter_below(:,j,m,1,k) = litter_below_old(:,j,m,1,k) - litter_above_flux(:,j,m,k)
!          ELSEWHERE ((litter_above_old(:,j,m,k)/(z_litter*1e-3) .GT. litter_below_old(:,j,m,1,k)/(zf_soil(1))) .AND. &
!                 ((litter_above_flux(:,j,m,k) - litter_above_old(:,j,m,k)) .GE. min_stomate))
!           litter_above(:,j,m,k) = zero 
!           litter_below_old_buffer(:,j,m,1,k) = litter_above_old(:,j,m,k)
!           litter_below(:,j,m,1,k) = litter_below_old(:,j,m,1,k) + litter_above_old(:,j,m,k)
!          ELSEWHERE ((litter_above_old(:,j,m,k)/(z_litter*1e-3) .GT. litter_below_old(:,j,m,1,k)/(zf_soil(1))) .AND. &
!                 ((litter_above_old(:,j,m,k) - litter_above_flux(:,j,m,k)) .GT. min_stomate))
!           litter_above(:,j,m,k) = litter_above_old(:,j,m,k) - litter_above_flux(:,j,m,k)
!           litter_below_old_buffer(:,j,m,1,k) = litter_above_flux(:,j,m,k)
!           litter_below(:,j,m,1,k) = litter_below_old(:,j,m,1,k) + litter_above_flux(:,j,m,k)
!          ELSEWHERE
!           litter_above(:,j,m,k) = litter_above_old(:,j,m,k)
!           litter_below(:,j,m,1,k) = litter_below_old(:,j,m,1,k)
!          ENDWHERE
!     ENDDO ! End loop over litter pools
!   ENDDO ! End loop over elements
!
ENDDO ! End loop over PFT

!!!CALL CRYOTURBATE HERE
!!!
!            IF (ok_cryoturb) CALL cryoturbate_doc_POC(npts, dt, dayno, altmax_ind, DOC, carbon_32l, litter_below, &
!       'diffuse', cryoturbation_diff_k_in/(one_day*one_year), bioturbation_diff_k_in/(one_day*one_year), altmax_lastyear, fixed_cryoturbation_depth)
!
!
!            IF (ok_cryoturb) CALL cryoturbate_doc_POC(npts, dt, dayno, altmax_ind, DOC, carbon_32l, litter_below, &
!       'coefficients', cryoturbation_diff_k_in/(one_day*one_year), bioturbation_diff_k_in/(one_day*one_year), altmax_lastyear, fixed_cryoturbation_depth)    
!!!
!!!
!!!!!END LITTER FLUX ABOVE BELOW OLD BLOCK 
!!! 
!!! 
  !! 8. calculate fraction of total soil covered by dead leaves

   CALL deadleaf (npts, veget_max, dead_leaves, deadleaf_cover, sla_calc)

   !! 9. Check mass balance closure

   !! 9.1 Calculate components of the mass balance
   pool_end_after(:,:,:) = zero
   pool_end(:,:,:) = zero
   IF (ld_doc) THEN
      DO m = 2, nvm
         DO i = 1,nlitt
            DO l = 1, ndeep
               pool_end(:,m,icarbon) = pool_end(:,m,icarbon) + &
                    ( litter_below(:,i,m,l,icarbon) ) * veget_max(:,m)
            ENDDO
         ENDDO
      ENDDO

      DO m = 2, nvm
         DO i = 1,nlitt
            pool_end(:,m,icarbon) = pool_end(:,m,icarbon) + &
                 ( litter_above(:,i,m,icarbon) ) * veget_max(:,m)
         ENDDO
      ENDDO

    
    !! 9.2 Calculate mass balance
    !  Note that soilcarbon is transfered to other pools but that the pool
    !  was not updated. We should not account for it in ::pool_end

      check_intern(:,:,:,:) = zero
      check_intern(:,:,iatm2land,icarbon) = zero 

    
      check_intern(:,:,iland2atm,icarbon) = -un * (resp_hetero_litter(:,:,iabove)+resp_hetero_litter(:,:,ibelow)+resp_hetero_flood(:,:)) * &
           veget_max(:,:) * dt
    

      DO m = 1,nvm
         DO l = 1, ndeep
            check_intern(:,m,ilat2out,icarbon) = check_intern(:,m,ilat2out,icarbon) -un * &
                 (soilcarbon_input_DOC(:,m,l,imetbel,icarbon)+soilcarbon_input_DOC(:,m,l,istrbel,icarbon)) * &
                 veget_max(:,m) * dt
         ENDDO
      ENDDO
      DO m = 1,nvm
         check_intern(:,m,ilat2out,icarbon) = check_intern(:,m,ilat2out,icarbon) -un * &
              (soilcarbon_input_DOC(:,m,1,imetabo,icarbon)+soilcarbon_input_DOC(:,m,1,istrabo,icarbon)    &
              +floodcarbon_input(:,m,iact,icarbon)+floodcarbon_input(:,m,islo,icarbon)) * &
              veget_max(:,m) * dt
      ENDDO

      check_intern(:,:,ilat2in,icarbon) = zero
    
      check_intern(:,:,ipoolchange,icarbon) = -un * (pool_end(:,:,icarbon) - &
           pool_start(:,:,icarbon))
    
      closure_intern = zero
      DO i = 1,nmbcomp
         closure_intern(:,:,icarbon) = closure_intern(:,:,icarbon) + &
              check_intern(:,:,i,icarbon)
      ENDDO

    !! 9.3 Write verdict

      IF (SUM(SUM(closure_intern(:,:,icarbon),2),1) .LT. min_stomate .AND. &
           SUM(SUM(closure_intern(:,:,icarbon),2),1) .GT. -min_stomate) THEN
         WRITE(numout,*) 'Mass balance closure in stomate_litter.f90'
      ELSE
         WRITE(numout,*) 'Error: mass balance is not closed in stomate_litter.f90'
         WRITE(numout,*) '   Difference is, ', SUM(SUM(closure_intern(:,:,icarbon),2),1)
         WRITE(numout,*) '   Difference is, ', closure_intern(:,:,icarbon)
      ENDIF
   ENDIF



    CALL deadleaf (npts, veget_max, dead_leaves, deadleaf_cover, &!)
!gmjc
                   sla_calc)
!end gmjc

  !! 7. (Quasi-)Analytical Spin-up : Start filling MatrixA
! 
!     IF (spinup_analytic) THEN
! 
        MatrixA(:,:,:,:) = zero
        VectorB(:,:,:) = zero
!        
!        
!        DO m = 1,nvm
! 
!           !- MatrixA : carbon fluxes leaving the litter
!           
!           MatrixA(:,m,istrabo,istrabo)= - dt/litter_tau(istructural) * &
!                control_temp(:,iabove) * control_moist(:,iabove) * exp( -litter_struct_coef * lignin_struc(:,m,iabove) )
!           
!           MatrixA(:,m,istrbel,istrbel) = - dt/litter_tau(istructural) * &
!                control_temp(:,ibelow) * control_moist(:,ibelow) * exp( -litter_struct_coef * lignin_struc(:,m,ibelow) )
!           
!           MatrixA(:,m,imetabo,imetabo) = - dt/litter_tau(imetabolic) * & 
!                control_temp(:,iabove) * control_moist(:,iabove)
!           
!           MatrixA(:,m,imetbel,imetbel) = - dt/litter_tau(imetabolic) * & 
!                control_temp(:,ibelow) * control_moist(:,ibelow)
!           
!           
!           !- MatrixA : carbon fluxes between the litter and the pools (the rest of the matrix is filled in stomate_soilcarbon.f90)
!           
!           MatrixA(:,m,iact,istrabo) = frac_soil(istructural,iactive,iabove) * &
!                dt/litter_tau(istructural) * &                    
!                control_temp(:,iabove) * control_moist(:,iabove) * & 
!                exp( -litter_struct_coef * lignin_struc(:,m,iabove) ) * &
!                ( 1. - lignin_struc(:,m,iabove) ) 
!           
! 
!           MatrixA(:,m,iact,istrbel) = frac_soil(istructural,iactive,ibelow) * &
!                dt/litter_tau(istructural) * &                     
!                control_temp(:,ibelow) * control_moist(:,ibelow) * & 
!                exp( -litter_struct_coef * lignin_struc(:,m,ibelow) ) * &
!                ( 1. - lignin_struc(:,m,ibelow) ) 
!           
!           
!           MatrixA(:,m,iact,imetabo) =  frac_soil(imetabolic,iactive,iabove) * &
!                dt/litter_tau(imetabolic) * control_temp(:,iabove) * control_moist(:,iabove) 
!           
!           
!           MatrixA(:,m,iact,imetbel) =  frac_soil(imetabolic,iactive,ibelow) * &
!                dt/litter_tau(imetabolic) * control_temp(:,ibelow) * control_moist(:,ibelow)
!           
!           MatrixA(:,m,islo,istrabo) = frac_soil(istructural,islow,iabove) * &
!                dt/litter_tau(istructural) * &                   
!                control_temp(:,iabove) * control_moist(:,iabove) * &
!                exp( -litter_struct_coef * lignin_struc(:,m,iabove) )* &
!                lignin_struc(:,m,iabove)
!           
!           
!           MatrixA(:,m,islo,istrbel) = frac_soil(istructural,islow,ibelow) * &
!                dt/litter_tau(istructural) * &   
!                control_temp(:,ibelow) * control_moist(:,ibelow) *  &
!                   exp( -litter_struct_coef * lignin_struc(:,m,ibelow) )* &
!                   lignin_struc(:,m,ibelow) 
!           
!           
!           !- VectorB : carbon input -
!           
!           VectorB(:,m,istrabo) = litter_inc_PFT(:,m,istructural,iabove,icarbon)
!           VectorB(:,m,istrbel) = litter_inc_PFT(:,m,istructural,ibelow,icarbon)
!           VectorB(:,m,imetabo) = litter_inc_PFT(:,m,imetabolic,iabove,icarbon)
!           VectorB(:,m,imetbel) = litter_inc_PFT(:,m,imetabolic,ibelow,icarbon)
!           
!           IF (printlev>=4) WRITE(numout,*) 'We filled MatrixA and VectorB' 
!           
!        ENDDO ! Loop over # PFTs
!           
!     ENDIF ! spinup analytic 

    IF (printlev>=4) WRITE(numout,*) 'Leaving littercalc'

  END SUBROUTINE littercalc


!
!!!!!LITTERCALC_MICT
!!!
!! ================================================================================================================================
!! SUBROUTINE   : littercalc_MICT
!!
!!\BRIEF        Calculation of the litter decomposition and therefore of the 
!! heterotrophic respiration from litter following Parton et al. (1987). 
!! This is the original littercalc version in MICT r3668 (mid-2016) which is used
!! when OK_PC flag = T. 
!!
!! DESCRIPTION  : The littercal routine splits the litter in 4 pools: 
!! aboveground metaboblic, aboveground structural, belowground metabolic and 
!! belowground structural. the fraction (F) of plant material going to metabolic 
!! and structural is defined following Parton et al. (1987)
!! \latexonly
!! \input{littercalc_MICT1.tex}
!! \endlatexonly
!! \n
!! where L is the lignin content of the plant carbon pools considered and CN 
!! its CN ratio. L and CN are fixed parameters for each plant carbon pools,
!! therefore it is the ratio between each plant carbon pool within a PFT, which
!! controlled the part of the total litter, that will be considered as
!! recalcitrant (i.e. structural litter) or labile (i.e. metabolic litter).\n  
!! 
!! The routine calculates the fraction of aboveground litter which is metabolic
!! or structural (the litterpart variable) which is then used in lpj_fire.f90.\n 
!! 
!! In the section 2, the routine calculate the new plant material entering the
!! litter pools by phenological death of plants organs (corresponding to the
!! variable turnover) and by fire, herbivory and others non phenological causes
!! (variable bm_to_litter). This calculation is first done for each PFT and then
!! the values calculated for each PFT are added up. Following the same approach
!! the lignin content of the total structural litter is calculated and will be
!! then used as a factor control of the decomposition of the structural litter
!! (lignin_struc) in the section 5.1.2. A test is performed to avoid that we add
!! more lignin than structural litter. Finally, the variable litterpart is
!! updated.\n
!! 
!! In the section 3 and 4 the temperature and the moisture controlling the
!! decomposition are calculated for above and belowground. For aboveground
!! litter, air temperature and litter moisture are calculated in sechiba and used 
!! directly. For belowground, soil temperature and moisture are also calculated 
!! in sechiba but are modulated as a function of the soil depth. The modulation 
!! is a multiplying factor exponentially distributed between 0 (in depth) and 1
!! in surface.\n  
!! 
!! Then, in the section 5, the routine calculates the structural litter decomposition 
!! (C) following first order kinetics following Parton et al. (1987).
!! \latexonly
!! \input{littercalc_MICT2.tex}
!! \endlatexonly
!! \n
!! with k the decomposition rate of the structural litter. 
!! k corresponds to
!! \latexonly
!! \input{littercalc_MICT3.tex}
!! \endlatexonly
!! \n
!! with littertau the turnover rate, T a function of the temperature and M a function of
!! the moisture described below.\n
!!  
!! Then, the fraction of dead leaves (DL) composed by aboveground structural litter is
!! calculated as following
!! \latexonly
!! \input{littercalc_MICT4.tex}
!! \endlatexonly
!! \n
!! with k the decomposition rate of the structural litter previously
!! described.\n
!!
!! In the section 5.1, the fraction of decomposed structural litter
!! incorporated to the soil (Input) and its associated heterotrophic respiration are
!! calculated. For structural litter, the C decomposed could go in the active
!! soil carbon pool or in the slow carbon, as described in 
!! stomate_soilcarbon.f90.\n
!! \latexonly
!! \input{littercalc_MICT5.tex}
!! \endlatexonly
!! \n
!! with f a parameter describing the fraction of structural litter incorporated
!! into the considered soil carbon pool, C the amount of litter decomposed and L 
!! the amount of lignin in the litter. The litter decomposed which is not
!! incorporated into the soil is respired.\n
!!
!! In the section 5.2, the fraction of decomposed metabolic litter
!! incorporated to the soil and its associated heterotrophic respiration are
!! calculated with the same approaches presented for 5.1 but no control factor
!! depending on the lignin content are used.\n
!! 
!! In the section 6 the dead leaf cover is calculated through a call to the 
!! deadleaf subroutine presented below.\n
!!
!! In the section 7, if the flag SPINUP_ANALYTIC is set to true, we fill MatrixA
!! and VectorB following Lardy(2011).
!!
!! MAIN OUTPUT VARIABLES: ::deadleaf_cover, ::resp_hetero_litter, ::soilcarbon_input, 
!! ::control_temp, ::control_moist
!!
!! REFERENCES:
!! - Parton, WJ, Schimel, DS, Cole, CV, and Ojima, DS. 1987. Analysis
!! of factors controlling soil organic matter levels in Great Plains
!! grasslands. Soil Science Society of America journal (USA)
!! (51):1173-1179.
!! - Lardy, R, et al., A new method to determine soil organic carbon equilibrium,
!! Environmental Modelling & Software (2011), doi:10.1016|j.envsoft.2011.05.016
!!
!! FLOWCHART    :
!! \latexonly
!! \includegraphics(scale=0.5){littercalcflow.jpg}
!! \endlatexonly
!! \n
!_ ================================================================================================================================


  SUBROUTINE littercalc_MICT(npts, dt, &
       turnover, bm_to_litter, &
       veget_max, tsurf, tsoil, soilhum, litterhum, &
       litterpart, litter, litter_avail, litter_not_avail, litter_avail_frac, &
!spitfire
       fuel_1hr, fuel_10hr, fuel_100hr, fuel_1000hr, &
!endspit
       dead_leaves, lignin_struc, &
       deadleaf_cover, resp_hetero_litter, &
       soilcarbon_input, control_temp, control_moist, &
       MatrixA, VectorB, &!
!JCADD
       sla_calc,do_slow)
!ENDJCADD

    !! 0. Variable and parameter declaration
    
    !! 0.1 Input variables

    INTEGER(i_std), INTENT(in)                                  :: npts               !! Domain size - number of grid pixels
    REAL(r_std), INTENT(in)                                     :: dt                 !! Time step of the simulations for stomate
                                                                                      !! @tex $(dtradia one\_day^{-1})$ @endtex 
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements), INTENT(in) :: turnover           !! Turnover rates of plant biomass 
                                                                                      !! @tex $(gC m^{-2} dt\_slow^{-1})$ @endtex 
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements), INTENT(in) :: bm_to_litter     !! Conversion of biomass to litter 
                                                                                      !! @tex $(gC m^{-2} dt\_slow^{-1})$ @endtex 
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)                  :: veget_max          !! PFT "Maximal" coverage fraction of a PFT 
                                                                                      !! defined in the input vegetation map 
                                                                                      !! @tex $(m^2 m^{-2})$ @endtex 
    REAL(r_std), DIMENSION(npts), INTENT(in)                    :: tsurf              !! Temperature (K) at the surface
    REAL(r_std), DIMENSION(npts,nbdl), INTENT(in)               :: tsoil              !! Soil temperature (K)
    REAL(r_std), DIMENSION(npts,nbdl), INTENT(in)               :: soilhum            !! Daily soil humidity of each soil layer 
                                                                                      !! (unitless)
    REAL(r_std), DIMENSION(npts), INTENT(in)                    :: litterhum          !! Daily litter humidity (unitless)

    !! 0.2 Output variables
    
    REAL(r_std), DIMENSION(npts), INTENT(out)                   :: deadleaf_cover     !! Fraction of soil covered by dead leaves 
                                                                                      !! over all PFTs (0-1, unitless)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)               :: resp_hetero_litter !! Litter heterotrophic respiration. The unit
                                                                                      !! is given by m^2 of ground.  
                                                                                      !! @tex $(gC dtradia one\_day^{-1}) m^{-2})$ @endtex 
    REAL(r_std), DIMENSION(npts,ncarb,nvm), INTENT(out)         :: soilcarbon_input   !! Quantity of carbon going into carbon pools
                                                                                      !! from litter decomposition. The unit is  
                                                                                      !! given by m^2 of ground 
                                                                                      !! @tex $(gC m^{-2} dt\_slow^{-1})$ @endtex 
    REAL(r_std), DIMENSION(npts,nlevs), INTENT(out)             :: control_temp       !! Temperature control of heterotrophic 
                                                                                      !! respiration, above and below (0-1, 
                                                                                      !! unitless)
    REAL(r_std), DIMENSION(npts,nlevs), INTENT(out)             :: control_moist      !! Moisture control of heterotrophic 
                                                                                      !! respiration (0.25-1, unitless)
    REAL(r_std), DIMENSION(npts,nvm,nbpools,nbpools), INTENT(out) :: MatrixA          !! Matrix containing the fluxes between the
                                                                                      !! carbon pools per sechiba time step 
                                                                                      !! @tex $(gC.m^2.day^{-1})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nbpools), INTENT(out)         :: VectorB          !! Vector containing the litter increase per
                                                                                      !! sechiba time step
                                                                                      !! @tex $(gC m^{-2})$ @endtex
   
    !! 0.3 Modified variables
    
    REAL(r_std), DIMENSION(npts,nvm,nlitt), INTENT(inout)       :: litterpart         !! Fraction of litter above the ground 
                                                                                      !! belonging to the different PFTs (0-1, 
                                                                                      !! unitless)
    REAL(r_std), DIMENSION(npts,nlitt,nvm,nlevs,nelements), INTENT(inout) :: litter   !! Metabolic and structural litter,above and
                                                                                      !! below ground. The unit is given by m^2 of 
                                                                                      !! ground @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nlitt,nvm), INTENT(inout)       :: litter_avail
    REAL(r_std), DIMENSION(npts,nlitt,nvm), INTENT(in)       :: litter_not_avail
    REAL(r_std), DIMENSION(npts,nlitt,nvm), INTENT(out)       :: litter_avail_frac

    REAL(r_std), DIMENSION(npts,nvm,nlitt), INTENT(inout)       :: dead_leaves        !! Dead leaves per ground unit area, per PFT,
                                                                                      !! metabolic and structural in 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlevs), INTENT(inout)       :: lignin_struc       !! Ratio Lignin content in structural litter,
                                                                                      !! above and below ground, (0-1, unitless)
!JCADD
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)                  :: sla_calc
    LOGICAL,INTENT(in)                               :: do_slow
!ENDJCADD   
    !! 0.4 Local variables
 
    REAL(r_std), SAVE, DIMENSION(nparts,nlitt)                  :: litterfrac         !! The fraction of leaves, wood, etc. that 
                                                                                      !! goes into metabolic and structural 
                                                                                      !! litterpools (0-1, unitless)
!$OMP THREADPRIVATE(litterfrac)
!    REAL(r_std), SAVE, DIMENSION(0:nbdl)                        :: z_soil             !! Soil levels (m)
!$OMP THREADPRIVATE(z_soil)
    REAL(r_std), DIMENSION(npts)                                :: rpc                !! Integration constant for vertical root 
                                                                                      !! profiles (unitless)
    REAL(r_std), SAVE, DIMENSION(nlitt)                         :: litter_tau         !! Turnover time in litter pools (days)
!$OMP THREADPRIVATE(litter_tau)
    REAL(r_std), SAVE, DIMENSION(nlitt,ncarb,nlevs)             :: frac_soil          !! Fraction of litter that goes into soil 
                                                                                      !! (litter -> carbon, above and below). The
                                                                                      !! remaining part goes to the atmosphere
!$OMP THREADPRIVATE(frac_soil)
    REAL(r_std), DIMENSION(npts)                                :: tsoil_decomp       !! Temperature used for decompostition in 
                                                                                      !! soil (K)
    REAL(r_std), DIMENSION(npts)                                :: soilhum_decomp     !! Humidity used for decompostition in soil
                                                                                      !! (unitless)
    REAL(r_std), DIMENSION(npts)                                :: fd                 !! Fraction of structural or metabolic litter
                                                                                      !! decomposed (unitless)
    REAL(r_std), DIMENSION(npts,nelements)                      :: qd                 !! Quantity of structural or metabolic litter
                                                                                      !! decomposed @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlevs)                      :: old_struc          !! Old structural litter, above and below 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nlevs,nelements)      :: litter_inc_PFT     !! Increase of litter, per PFT, metabolic and
                                                                                      !! structural, above and below ground. The 
                                                                                      !! unit is given by m^2 of ground.  
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nlitt,nvm,nlevs,nelements)      :: litter_inc         !! Increase of metabolic and structural 
                                                                                      !! litter, above and below ground. The unit 
                                                                                      !! is given by m^2 of ground. 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlevs)                      :: lignin_struc_inc   !! Lignin increase in structural litter, 
                                                                                      !! above and below ground. The unit is given 
                                                                                      !! by m^2 of ground. 
                                                                                      !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements)            :: litter_pft         !! Metabolic and structural litter above the 
                                                                                      !! ground per PFT
    REAL(r_std), DIMENSION(npts)                                :: zdiff_min          !! Intermediate field for looking for minimum
                                                                                      !! of what? this is not used in the code. 
                                                                                      !! [??CHECK] could we delete it?
    CHARACTER(LEN=10), DIMENSION(nlitt)                         :: litter_str         !! Messages to write output information about
                                                                                      !! the litter
    CHARACTER(LEN=22), DIMENSION(nparts)                        :: part_str           !! Messages to write output information about
                                                                                      !! the plant
    CHARACTER(LEN=7), DIMENSION(ncarb)                          :: carbon_str         !! Messages to write output information about
                                                                                      !! the soil carbon
    CHARACTER(LEN=5), DIMENSION(nlevs)                          :: level_str          !! Messages to write output information about
                                                                                      !! the level (aboveground or belowground litter)
    INTEGER(i_std)                                              :: i,j,k,l,m          !! Indices (unitless)
    INTEGER(i_std), SAVE                                        :: frozen_respiration_func = 0
    LOGICAL, SAVE                                               :: use_snowinsul_litter_resp = .FALSE.

!spitfire
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements),INTENT(inout)        :: fuel_1hr
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements),INTENT(inout)        :: fuel_10hr
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements),INTENT(inout)        :: fuel_100hr
    REAL(r_std), DIMENSION(npts,nvm,nlitt,nelements),INTENT(inout)        :: fuel_1000hr
    !total fuel load summing together all fuel classes.
    REAl(r_std), DIMENSION(npts,nvm,nlitt,nelements)                      :: fuel_nlitt_total_pft
    ! difference between litter and fuel_nlitt_total_pft
    REAL(r_std), DIMENSION(npts)                                :: diff_frac
    ! quantity of structural or metabolic litter decomposed (gC/m**2) for decomposing fuel classes per PFT
    ! chaocomm: this is now only a temporary variable and will be deleted later.
    REAL(r_std), DIMENSION(npts,nelements)                                :: qd_fuel
!endspit
!_ ================================================================================================================================

!!!    IF (bavard.GE.3) WRITE(numout,*) 'Entering littercalc_MICT'

  !! 1. Initialisations of the different fields during the first call of the routine 

    IF ( firstcall ) THEN

       !! 1.1.3 litter fractions:
       !!   what fraction of leaves, wood, etc. goes into metabolic and structural litterpools
       DO k = 1, nparts

          litterfrac(k,imetabolic) = metabolic_ref_frac - metabolic_LN_ratio * LC(k) * CN(k)
          litterfrac(k,istructural) = un - litterfrac(k,imetabolic)

       ENDDO

       !! 1.1.4 residence times in litter pools (days)
       litter_tau(imetabolic) = tau_metabolic * one_year      ! .5 years
       litter_tau(istructural) = tau_struct * one_year     ! 3 years

       !! 1.1.5 decomposition flux fraction that goes into soil
       !       (litter -> carbon, above and below)
       !       1-frac_soil goes into atmosphere
       frac_soil(:,:,:) = zero

       ! structural litter: lignin fraction goes into slow pool + respiration,
       !                    rest into active pool + respiration
       frac_soil(istructural,iactive,iabove) = frac_soil_struct_aa
       frac_soil(istructural,iactive,ibelow) = frac_soil_struct_ab
       frac_soil(istructural,islow,iabove) = frac_soil_struct_sa
       frac_soil(istructural,islow,ibelow) = frac_soil_struct_sb

       ! metabolic litter: all goes into active pool + respiration.
       !   Nothing into slow or passive pool.
       frac_soil(imetabolic,iactive,iabove) = frac_soil_metab_aa
       frac_soil(imetabolic,iactive,ibelow) = frac_soil_metab_ab

       
       !! 1.2 soil levels
       z_soil(0) = zero
       z_soil(1:nbdl) = diaglev(1:nbdl)

       
       !! 1.3 messages
       litter_str(imetabolic) = 'metabolic'
       litter_str(istructural) = 'structural'

       carbon_str(iactive) = 'active'
       carbon_str(islow) = 'slow'
       carbon_str(ipassive) = 'passive'

       level_str(iabove) = 'above'
       level_str(ibelow) = 'below'

       part_str(ileaf) = 'leaves'
       part_str(isapabove) = 'sap above ground'
       part_str(isapbelow) = 'sap below ground'
       part_str(iheartabove) = 'heartwood above ground'
       part_str(iheartbelow) = 'heartwood below ground'
       part_str(iroot) = 'roots'
       part_str(ifruit) = 'fruits'
       part_str(icarbres) = 'carbohydrate reserve'

       WRITE(numout,*) 'litter:'

       WRITE(numout,*) '   > C/N ratios: '
       DO k = 1, nparts
          WRITE(numout,*) '       ', part_str(k), ': ',CN(k)
       ENDDO

       WRITE(numout,*) '   > Lignine/C ratios: '
       DO k = 1, nparts
          WRITE(numout,*) '       ', part_str(k), ': ',LC(k)
       ENDDO

       WRITE(numout,*) '   > fraction of compartment that goes into litter: '
       DO k = 1, nparts
          DO m = 1, nlitt
             WRITE(numout,*) '       ', part_str(k), '-> ',litter_str(m), ':',litterfrac(k,m)
          ENDDO
       ENDDO

       WRITE(numout,*) '   > scaling depth for decomposition (m): ',z_decomp

       WRITE(numout,*) '   > minimal carbon residence time in litter pools (d):'
       DO m = 1, nlitt
          WRITE(numout,*) '       ',litter_str(m),':',litter_tau(m)
       ENDDO

       WRITE(numout,*) '   > litter decomposition flux fraction that really goes '
       WRITE(numout,*) '     into carbon pools (rest into the atmosphere):'
       DO m = 1, nlitt
          DO l = 1, nlevs
             DO k = 1, ncarb
                WRITE(numout,*) '       ',litter_str(m),' ',level_str(l),' -> ',&
                     carbon_str(k),':', frac_soil(m,k,l)
             ENDDO
          ENDDO
       ENDDO

       CALL getin_p('frozen_respiration_func',frozen_respiration_func)
       WRITE(numout, *)' frozen litter respiration function: ', frozen_respiration_func

       CALL getin_p('use_snowinsul_litter_resp',use_snowinsul_litter_resp)
       WRITE(numout, *)' use_snowinsul_litter_resp ( i.e. set surface litter temp to below snow layer:) ', use_snowinsul_litter_resp

       firstcall = .FALSE.

    ENDIF

    
    !! 1.3 litter above the ground per PFT.
    DO j = 1, nvm ! Loop over # PFTs

       DO k = 1, nlitt !Loop over litter pool
          litter_pft(:,j,k,icarbon) = litterpart(:,j,k) * litter(:,k,j,iabove,icarbon)
       ENDDO

    ENDDO

    
    !! 1.4 set output to zero
    deadleaf_cover(:) = zero
    resp_hetero_litter(:,:) = zero
    soilcarbon_input(:,:,:) = zero

    
  !! 2. Add biomass to different litterpools (per m^2 of ground)
    
    !! 2.1 first, save old structural litter (needed for lignin fractions).
    !     above/below
    DO l = 1, nlevs !Loop over litter levels (above and below ground)
       DO m = 1,nvm !Loop over PFTs

          old_struc(:,m,l) = litter(:,istructural,m,l,icarbon)

       ENDDO
    ENDDO

    
    !! 2.2 update litter, dead leaves, and lignin content in structural litter
    litter_inc(:,:,:,:,:) = zero
    lignin_struc_inc(:,:,:) = zero

    DO j = 1,nvm !Loop over PFTs

       !! 2.2.1 litter
       DO k = 1, nlitt    !Loop over litter pools (metabolic and structural)

          !! 2.2.2 calculate litter increase (per m^2 of ground).
          !       Only a given fracion of fruit turnover is directly coverted into litter.
          !       Litter increase for each PFT, structural and metabolic, above/below
          litter_inc_PFT(:,j,k,iabove,icarbon) = &
               litterfrac(ileaf,k) * bm_to_litter(:,j,ileaf,icarbon) + &
               litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
               litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
               litterfrac(ifruit,k) * bm_to_litter(:,j,ifruit,icarbon) + &
               litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
               litterfrac(ileaf,k) * turnover(:,j,ileaf,icarbon) + &
               litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
               litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
               litterfrac(ifruit,k) * turnover(:,j,ifruit,icarbon) + &
               litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon)

          litter_inc_PFT(:,j,k,ibelow,icarbon) = &
               litterfrac(isapbelow,k) * bm_to_litter(:,j,isapbelow,icarbon) + &
               litterfrac(iheartbelow,k) * bm_to_litter(:,j,iheartbelow,icarbon) + &
               litterfrac(iroot,k) * bm_to_litter(:,j,iroot,icarbon) + &
               litterfrac(isapbelow,k) * turnover(:,j,isapbelow,icarbon) + &
               litterfrac(iheartbelow,k) * turnover(:,j,iheartbelow,icarbon) + &
               litterfrac(iroot,k) * turnover(:,j,iroot,icarbon)

          ! litter increase, met/struct, above/below
          litter_inc(:,k,j,iabove,icarbon) = litter_inc(:,k,j,iabove,icarbon) + litter_inc_PFT(:,j,k,iabove,icarbon)
          litter_inc(:,k,j,ibelow,icarbon) = litter_inc(:,k,j,ibelow,icarbon) + litter_inc_PFT(:,j,k,ibelow,icarbon)

          !! 2.2.3 dead leaves, for soil cover.
          dead_leaves(:,j,k) = &
               dead_leaves(:,j,k) + &
               litterfrac(ileaf,k) * ( bm_to_litter(:,j,ileaf,icarbon) + turnover(:,j,ileaf,icarbon) )

          !! 2.2.4 lignin increase in structural litter
          IF ( k .EQ. istructural ) THEN

             lignin_struc_inc(:,j,iabove) = &
                  lignin_struc_inc(:,j,iabove) + &
                  LC(ileaf) * bm_to_litter(:,j,ileaf,icarbon) + &
                  LC(isapabove) * bm_to_litter(:,j,isapabove,icarbon) + &
                  LC(iheartabove) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  LC(ifruit) * bm_to_litter(:,j,ifruit,icarbon) + &
                  LC(icarbres) * bm_to_litter(:,j,icarbres,icarbon) + &
                  LC(ileaf) * turnover(:,j,ileaf,icarbon) + &
                  LC(isapabove) * turnover(:,j,isapabove,icarbon) + &
                  LC(iheartabove) * turnover(:,j,iheartabove,icarbon) + &
                  LC(ifruit) * turnover(:,j,ifruit,icarbon) + &
                  LC(icarbres) * turnover(:,j,icarbres,icarbon)

             lignin_struc_inc(:,j,ibelow) = &
                  lignin_struc_inc(:,j,ibelow) + &
                  LC(isapbelow) * bm_to_litter(:,j,isapbelow,icarbon) + &
                  LC(iheartbelow) * bm_to_litter(:,j,iheartbelow,icarbon) + &
                  LC(iroot) * bm_to_litter(:,j,iroot,icarbon) + &
                  LC(isapbelow)*turnover(:,j,isapbelow,icarbon) + &
                  LC(iheartbelow)*turnover(:,j,iheartbelow,icarbon) + &
                  LC(iroot)*turnover(:,j,iroot,icarbon)

          ENDIF

          !spitfire
          !calculate fuel amount
             fuel_1hr(:,j,k,icarbon) = fuel_1hr(:,j,k,icarbon) + &
                  1.0 * (litterfrac(ileaf,k) * bm_to_litter(:,j,ileaf,icarbon) + &
                  litterfrac(ileaf,k) * turnover(:,j,ileaf,icarbon) + &
                  litterfrac(ifruit,k) * bm_to_litter(:,j,ifruit,icarbon) + &
                  litterfrac(ifruit,k) * turnover(:,j,ifruit,icarbon)) + &
                  0.0450 * (litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
                  litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
                  litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
                  litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
                  litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon) )
             

             fuel_10hr(:,j,k,icarbon) = fuel_10hr(:,j,k,icarbon) + &
                  0.0750 * (litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
                  litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
                  litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
                  litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
                  litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon))
             
             fuel_100hr(:,j,k,icarbon) = fuel_100hr(:,j,k,icarbon) + &
                  0.2100 * (litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
                  litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
                  litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
                  litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
                  litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon))

             fuel_1000hr(:,j,k,icarbon) = fuel_1000hr(:,j,k,icarbon) + &
                  0.6700 * (litterfrac(isapabove,k) * bm_to_litter(:,j,isapabove,icarbon) + &
                  litterfrac(isapabove,k) * turnover(:,j,isapabove,icarbon) + &
                  litterfrac(iheartabove,k) * bm_to_litter(:,j,iheartabove,icarbon) + &
                  litterfrac(iheartabove,k) * turnover(:,j,iheartabove,icarbon) + &
                  litterfrac(icarbres,k) * bm_to_litter(:,j,icarbres,icarbon) + &
                  litterfrac(icarbres,k) * turnover(:,j,icarbres,icarbon))             
             
             fuel_nlitt_total_pft(:,j,k,icarbon) = fuel_1hr(:,j,k,icarbon) + fuel_10hr(:,j,k,icarbon) + &
                  fuel_100hr(:,j,k,icarbon) + fuel_1000hr(:,j,k,icarbon)
             
          !endspit
       ENDDO
    ENDDO

    !! 2.2.5 add new litter (struct/met, above/below)
    litter(:,:,:,:,:) = litter(:,:,:,:,:) + litter_inc(:,:,:,:,:)
!JCADD for grazing litter
    IF (do_slow) THEN
      DO j=2,nvm 
        IF (is_grassland_manag(j) .AND. is_grassland_grazed(j)) THEN
          WHERE (litter(:,:,j,iabove,icarbon) .GE. litter_not_avail(:,:,j) &
             .AND. litter(:,:,j,iabove,icarbon) .GT. 0.0)
            litter_avail_frac(:,:,j) = (litter(:,:,j,iabove,icarbon) - litter_not_avail(:,:,j)) & 
                  & / litter(:,:,j,iabove,icarbon)
          ! if litter not available equal to or larger than litter
          ELSEWHERE 
            litter_avail_frac(:,:,j) = 0.0
          ENDWHERE
          IF (ANY(litter_avail_frac .LT. 0.0)) THEN
            WRITE (numout,*) 'frac error',litter(:,:,j,iabove,icarbon),litter_not_avail(:,:,j),litter_avail_frac(:,:,j)
            STOP 'error fraction litter available for grazing < 0'
          ENDIF
        ELSE
          litter_avail_frac(:,:,j) = 1.0
        ENDIF
      ENDDO
    ENDIF
!ENDJCADD
    !! 2.2.6 for security: can't add more lignin than structural litter (above/below)
    DO l = 1, nlevs !Loop over litter levels (above and below ground)
       DO m = 1,nvm !Lopp over PFTs

          lignin_struc_inc(:,m,l) = &
               MIN( lignin_struc_inc(:,m,l), litter_inc(:,istructural,m,l,icarbon) )

       ENDDO
    ENDDO

    !! 2.2.7 new lignin content: add old lignin and lignin increase, divide by 
    !!       total structural litter (above/below)
    DO l = 1, nlevs !Loop over litter levels (above and below ground)
       DO m = 1,nvm !Loop over PFTs
          WHERE( litter(:,istructural,m,l,icarbon) .GT. min_stomate )

       !MM : Soenke modif
       ! Best vectorization ?
!!$       lignin_struc(:,:,:) = &
!!$            ( lignin_struc(:,:,:)*old_struc(:,:,:) + lignin_struc_inc(:,:,:) ) / &
!!$            litter(:,istructural,:,:,icarbon)

             lignin_struc(:,m,l) = lignin_struc(:,m,l) * old_struc(:,m,l)
             lignin_struc(:,m,l) = lignin_struc(:,m,l) + lignin_struc_inc(:,m,l)
             lignin_struc(:,m,l) = lignin_struc(:,m,l) / litter(:,istructural,m,l,icarbon)
          ELSEWHERE
             lignin_struc(:,m,l) = zero
          ENDWHERE
       ENDDO
    ENDDO

    
    !! 2.3 new litter fraction per PFT (for structural and metabolic litter, above
    !!       the ground).
    DO j = 1,nvm !Loop over PFTs

       WHERE ( litter(:,:,j,iabove,icarbon) .GT. min_stomate )

          litterpart(:,j,:) = &
               ( litter_pft(:,j,:,icarbon) + litter_inc_PFT(:,j,:,iabove,icarbon) ) / litter(:,:,j,iabove,icarbon)

       ELSEWHERE

          litterpart(:,j,:) = zero

       ENDWHERE

    ENDDO

    
  !! 3. Temperature control on decay: Factor between 0 and 1

    !! 3.1 above: surface temperature
    control_temp(:,iabove) = control_temp_func (npts,tsurf,frozen_respiration_func)

    
    !! 3.2 below: convolution of temperature and decomposer profiles
    !!            (exponential decomposer profile supposed)
   
    !! 3.2.1 rpc is an integration constant such that the integral of the root profile is 1.
    rpc(:) = un / ( un - EXP( -z_soil(nbdl) / z_decomp ) )

    !! 3.2.2 integrate over the nbdl levels
    tsoil_decomp(:) = zero

    DO l = 1, nbdl

       tsoil_decomp(:) = &
            tsoil_decomp(:) + tsoil(:,l) * rpc(:) * &
            ( EXP( -z_soil(l-1)/z_decomp ) - EXP( -z_soil(l)/z_decomp ) )

    ENDDO

    control_temp(:,ibelow) = control_temp_func (npts,tsoil_decomp,frozen_respiration_func)

  !! 4. Moisture control. Factor between 0 and 1
    
    !! 4.1 above the ground: litter humidity
    control_moist(:,iabove) = control_moist_func (npts, litterhum)

    !
    !! 4.2 below: convolution of humidity and decomposer profiles
    !            (exponential decomposer profile supposed)

    !! 4.2.1 rpc is an integration constant such that the integral of the root profile is 1.
    rpc(:) = un / ( un - EXP( -z_soil(nbdl) / z_decomp ) )

    !! 4.2.2 integrate over the nbdl levels
    soilhum_decomp(:) = zero

    DO l = 1, nbdl !Loop over soil levels

       soilhum_decomp(:) = &
            soilhum_decomp(:) + soilhum(:,l) * rpc(:) * &
            ( EXP( -z_soil(l-1)/z_decomp ) - EXP( -z_soil(l)/z_decomp ) )

    ENDDO

    control_moist(:,ibelow) = control_moist_func (npts, soilhum_decomp)

  !! 5. fluxes from litter to carbon pools and respiration

    DO l = 1, nlevs !Loop over litter levels (above and below ground)
       DO m = 1,nvm !Loop over PFTs

          !! 5.1 structural litter: goes into active and slow carbon pools + respiration

          !! 5.1.1 total quantity of structural litter which is decomposed
          fd(:) = dt/litter_tau(istructural) * &
               control_temp(:,l) * control_moist(:,l) * exp( -litter_struct_coef * lignin_struc(:,m,l) )

          DO k = 1,nelements
             
             qd(:,k) = litter(:,istructural,m,l,k) * fd(:)

          END DO

          litter(:,istructural,m,l,:) = litter(:,istructural,m,l,:) - qd(:,:)
          !spitfire
          !update the fuel poop size accordingly after respiration
          qd_fuel(:,:)=qd(:,:)

          IF(l==iabove) THEN
             WHERE (fuel_nlitt_total_pft(:,m,istructural,icarbon).GT.0.0 .AND. qd_fuel(:,icarbon).GT.0.0)
                
                fuel_1hr(:,m,istructural,icarbon) = fuel_1hr(:,m,istructural,icarbon) - (qd_fuel(:,icarbon) * &    
                     fuel_1hr(:,m,istructural,icarbon)/fuel_nlitt_total_pft(:,m,istructural,icarbon))
                
                fuel_10hr(:,m,istructural,icarbon) = fuel_10hr(:,m,istructural,icarbon) - (qd_fuel(:,icarbon) * &    
                     fuel_10hr(:,m,istructural,icarbon)/fuel_nlitt_total_pft(:,m,istructural,icarbon))
                
                fuel_100hr(:,m,istructural,icarbon) = fuel_100hr(:,m,istructural,icarbon) - (qd_fuel(:,icarbon) * &    
                     fuel_100hr(:,m,istructural,icarbon)/fuel_nlitt_total_pft(:,m,istructural,icarbon))
                
                fuel_1000hr(:,m,istructural,icarbon) = fuel_1000hr(:,m,istructural,icarbon) - (qd_fuel(:,icarbon) * &
                     fuel_1000hr(:,m,istructural,icarbon)/fuel_nlitt_total_pft(:,m,istructural,icarbon))
                
                fuel_nlitt_total_pft(:,m,istructural,icarbon) = fuel_1hr(:,m,istructural,icarbon) + &
                     fuel_10hr(:,m,istructural,icarbon) + fuel_100hr(:,m,istructural,icarbon) + & 
                     fuel_1000hr(:,m,istructural,icarbon)

                diff_frac(:) = litter(:,istructural,m,l,icarbon) - fuel_nlitt_total_pft(:,m,istructural,icarbon)
                WHERE(diff_frac(:).GT.min_stomate .OR. -1.0*diff_frac(:).GT.min_stomate)
                   ! simply divided even fraction to each fuel class, that is 1/4 of buffer
                   fuel_1hr(:,m,istructural,icarbon) = fuel_1hr(:,m,istructural,icarbon) + 0.25 * diff_frac(:)
                   fuel_10hr(:,m,istructural,icarbon) = fuel_10hr(:,m,istructural,icarbon) + 0.25 * diff_frac(:)
                   fuel_100hr(:,m,istructural,icarbon) = fuel_100hr(:,m,istructural,icarbon) + 0.25 * diff_frac(:)
                   fuel_1000hr(:,m,istructural,icarbon) = fuel_1000hr(:,m,istructural,icarbon) + 0.25 * diff_frac(:)
                   fuel_nlitt_total_pft(:,m,istructural,icarbon) = fuel_1hr(:,m,istructural,icarbon) + &
                        fuel_10hr(:,m,istructural,icarbon) + fuel_100hr(:,m,istructural,icarbon) + & 
                        fuel_1000hr(:,m,istructural,icarbon)
                ENDWHERE
             ENDWHERE
          ENDIF
    
          !endspit

          !! 5.1.2 decompose same fraction of structural part of dead leaves. Not exact
          !!       as lignine content is not the same as that of the total structural litter.
          ! to avoid a multiple (for ibelow and iabove) modification of dead_leaves,
          ! we do this test to do this calcul only ones in 1,nlev loop
          if (l == iabove)  dead_leaves(:,m,istructural) = dead_leaves(:,m,istructural) * ( un - fd(:) )

          !! 5.1.3 non-lignin fraction of structural litter goes into
          !!       active carbon pool + respiration
          soilcarbon_input(:,iactive,m) = soilcarbon_input(:,iactive,m) + &
               frac_soil(istructural,iactive,l) * qd(:,icarbon) * ( 1. - lignin_struc(:,m,l) ) / dt

      !BE CAREFUL: Here resp_hetero_litter is divided by dt to have a value which corresponds to
      ! the sechiba time step but then in stomate.f90 resp_hetero_litter is multiplied by dt.
      ! Perhaps it could be simplified. Moreover, we must totally adapt the routines to the dtradia/one_day
      ! time step and avoid some constructions that could create bug during future developments.
          resp_hetero_litter(:,m) = resp_hetero_litter(:,m) + &
               ( 1. - frac_soil(istructural,iactive,l) ) * qd(:,icarbon) * &
               ( 1. - lignin_struc(:,m,l) ) / dt

          !! 5.1.4 lignin fraction of structural litter goes into
          !!       slow carbon pool + respiration
          soilcarbon_input(:,islow,m) = soilcarbon_input(:,islow,m) + &
               frac_soil(istructural,islow,l) * qd(:,icarbon) * lignin_struc(:,m,l) / dt

      !BE CAREFUL: Here resp_hetero_litter is divided by dt to have a value which corresponds to
      ! the sechiba time step but then in stomate.f90 resp_hetero_litter is multiplied by dt.
      ! Perhaps it could be simplified. Moreover, we must totally adapt the routines to the dtradia/one_day
      ! time step and avoid some constructions that could create bug during future developments.
          resp_hetero_litter(:,m) = resp_hetero_litter(:,m) + &
               ( 1. - frac_soil(istructural,islow,l) ) * qd(:,icarbon) * lignin_struc(:,m,l) / dt

          
          !! 5.2 metabolic litter goes into active carbon pool + respiration
         
          !! 5.2.1 total quantity of metabolic litter that is decomposed
          fd(:) = dt/litter_tau(imetabolic) * control_temp(:,l) * control_moist(:,l)

          DO k = 1,nelements
          
             qd(:,k) = litter(:,imetabolic,m,l,k) * fd(:)

          END DO

          litter(:,imetabolic,m,l,:) = litter(:,imetabolic,m,l,:) - qd(:,:)
         
          !spitfire
          !update aboveground fuel load
          qd_fuel(:,:) = qd(:,:)

          IF(l==iabove) THEN
             WHERE (fuel_nlitt_total_pft(:,m,imetabolic,icarbon).gt.0.0 .and. qd_fuel(:,icarbon).gt.0.0)
                fuel_1hr(:,m,imetabolic,icarbon) = fuel_1hr(:,m,imetabolic,icarbon) - (qd_fuel(:,icarbon) * &
                     fuel_1hr(:,m,imetabolic,icarbon)/fuel_nlitt_total_pft(:,m,imetabolic,icarbon))
                
                fuel_10hr(:,m,imetabolic,icarbon) = fuel_10hr(:,m,imetabolic,icarbon) - (qd_fuel(:,icarbon) * &
                     fuel_10hr(:,m,imetabolic,icarbon)/fuel_nlitt_total_pft(:,m,imetabolic,icarbon))
                
                fuel_100hr(:,m,imetabolic,icarbon) = fuel_100hr(:,m,imetabolic,icarbon) - (qd_fuel(:,icarbon) * &
                     fuel_100hr(:,m,imetabolic,icarbon)/fuel_nlitt_total_pft(:,m,imetabolic,icarbon))
                
                fuel_1000hr(:,m,imetabolic,icarbon) = fuel_1000hr(:,m,imetabolic,icarbon) - (qd_fuel(:,icarbon) * &
                     fuel_1000hr(:,m,imetabolic,icarbon)/fuel_nlitt_total_pft(:,m,imetabolic,icarbon))
                
                fuel_nlitt_total_pft(:,m,imetabolic,icarbon) = fuel_1hr(:,m,imetabolic,icarbon) + &
                     fuel_10hr(:,m,imetabolic,icarbon) + fuel_100hr(:,m,imetabolic,icarbon) + &
                     fuel_1000hr(:,m,imetabolic,icarbon)

                diff_frac(:) = litter(:,imetabolic,m,l,icarbon) - fuel_nlitt_total_pft(:,m,imetabolic,icarbon)
                WHERE(diff_frac(:).GT.min_stomate .OR. -1.0*diff_frac(:).GT.min_stomate)
                   ! simply divided even fraction to each fuel class, that is 1/4 of buffer
                   fuel_1hr(:,m,imetabolic,icarbon) = fuel_1hr(:,m,imetabolic,icarbon) + 0.25 * diff_frac(:)
                   fuel_10hr(:,m,imetabolic,icarbon) = fuel_10hr(:,m,imetabolic,icarbon) + 0.25 * diff_frac(:)
                   fuel_100hr(:,m,imetabolic,icarbon) = fuel_100hr(:,m,imetabolic,icarbon) + 0.25 * diff_frac(:)
                   fuel_1000hr(:,m,imetabolic,icarbon) = fuel_1000hr(:,m,imetabolic,icarbon) + 0.25 * diff_frac(:)
                   fuel_nlitt_total_pft(:,m,imetabolic,icarbon) = fuel_1hr(:,m,imetabolic,icarbon) + &
                        fuel_10hr(:,m,imetabolic,icarbon) + fuel_100hr(:,m,imetabolic,icarbon) + &
                        fuel_1000hr(:,m,imetabolic,icarbon)
                ENDWHERE
             ENDWHERE
          ENDIF
          !endspit

          !! 5.2.2 decompose same fraction of metabolic part of dead leaves.
          !  to avoid a multiple (for ibelow and iabove) modification of dead_leaves,
          !  we do this test to do this calcul only ones in 1,nlev loop
          if (l == iabove)  dead_leaves(:,m,imetabolic) = dead_leaves(:,m,imetabolic) * ( 1. - fd(:) )


          !! 5.2.3 put decomposed litter into carbon pool + respiration
          soilcarbon_input(:,iactive,m) = soilcarbon_input(:,iactive,m) + &
               frac_soil(imetabolic,iactive,l) * qd(:,icarbon) / dt

      !BE CAREFUL: Here resp_hetero_litter is divided by dt to have a value which corresponds to
      ! the sechiba time step but then in stomate.f90 resp_hetero_litter is multiplied by dt.
      ! Perhaps it could be simplified. Moreover, we must totally adapt the routines to the dtradia/one_day
      ! time step and avoid some constructions that could create bug during future developments.
          resp_hetero_litter(:,m) = resp_hetero_litter(:,m) + &
               ( 1. - frac_soil(imetabolic,iactive,l) ) * qd(:,icarbon) / dt

       ENDDO
    ENDDO

    
  !! 6. calculate fraction of total soil covered by dead leaves

    CALL deadleaf (npts, veget_max, dead_leaves, deadleaf_cover, &!)
!JCADD
                   sla_calc)
!ENDJCADD

  !! 7. (Quasi-)Analytical Spin-up : Start filling MatrixA

    IF (spinup_analytic) THEN

       MatrixA(:,:,:,:) = zero
       VectorB(:,:,:) = zero
       

 !!   IF (bavard.GE.4) WRITE(numout,*) 'Leaving littercalc_MICT'
 END IF
  END SUBROUTINE littercalc_MICT





!! ==============================================================================================================================\n
!! SUBROUTINE   : deadleaf
!!
!>\BRIEF        This routine calculates the deadleafcover. 
!!
!! DESCRIPTION  : It first calculates the lai corresponding to the dead leaves (LAI) using 
!! the dead leaves carbon content (DL) the specific leaf area (sla) and the 
!! maximal coverage fraction of a PFT (vegetmax) using the following equations:
!! \latexonly
!! \input{deadleaf1.tex}
!! \endlatexonly
!! \n
!! Then, the dead leaf cover (DLC) is calculated as following:\n
!! \latexonly
!! \input{deadleaf2.tex}
!! \endlatexonly
!! \n
!! 
!! RECENT CHANGE(S) : None
!!
!! MAIN OUTPUT VARIABLE: ::deadleaf_cover
!! 
!! REFERENCE(S) : None
!!
!! FLOWCHART : None
!! \n
!_ ================================================================================================================================

  SUBROUTINE deadleaf (npts, veget_max, dead_leaves, deadleaf_cover, &
!gmjc
                       sla_calc)
!end gmjc
  !! 0. Variable and parameter declaration
    
    !! 0.1 Input variables

    INTEGER(i_std), INTENT(in)                          :: npts           !! Domain size - number of grid pixels (unitless)
    REAL(r_std), DIMENSION(npts,nvm,nlitt), INTENT(in)  :: dead_leaves    !! Dead leaves per ground unit area, per PFT, 
                                                                          !! metabolic and structural  
                                                                          !! @tex $(gC m^{-2})$ @endtex
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)          :: veget_max      !! PFT "Maximal" coverage fraction of a PFT defined in 
                                                                          !! the input vegetation map 
                                                                          !! @tex $(m^2 m^{-2})$ @endtex 
    
    !! 0.2 Output variables
    
    REAL(r_std), DIMENSION(npts), INTENT(out)           :: deadleaf_cover !! Fraction of soil covered by dead leaves over all PFTs
                                                                          !! (0-1, unitless)
!gmjc
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)                 :: sla_calc
!end gmjc
    !! 0.3 Modified variables

    !! 0.4 Local variables

    REAL(r_std), DIMENSION(npts)                        :: dead_lai       !! LAI of dead leaves @tex $(m^2 m^{-2})$ @endtex
    INTEGER(i_std)                                      :: j              !! Index (unitless)
!_ ================================================================================================================================
    
  !! 1. LAI of dead leaves
  
    dead_lai(:) = zero

    DO j = 1,nvm !Loop over PFTs
!JCMODIF
!       dead_lai(:) = dead_lai(:) + ( dead_leaves(:,j,imetabolic) + dead_leaves(:,j,istructural) ) * sla(j) &
       dead_lai(:) = dead_lai(:) + ( dead_leaves(:,j,imetabolic) + &
                     dead_leaves(:,j,istructural) ) * sla_calc(:,j) &
!ENDJCMODIF
            * veget_max(:,j)
    ENDDO

  !! 2. fraction of soil covered by dead leaves

    deadleaf_cover(:) = un - exp( - 0.5 * dead_lai(:) )

    IF (printlev>=4) WRITE(numout,*) 'Leaving deadleaf'

  END SUBROUTINE deadleaf


!!!SIMON ADDED control_moist_func_moyano
!! ================================================================================================================================
!! FUNCTION     : control_moist_func_moyano
!!
!>\BRIEF        Calculate moisture control for litter and soild C decomposition
!!
!! DESCRIPTION  : Calculate moisture control factor applied
!! to litter decomposition and to soil carbon decomposition in
!! stomate_soilcarbon.f90 using the following equation: \n
!! \latexonly
!! \input{control_moist_func1.tex}
!! \endlatexonly
!! \n
!! with M the moisture control factor and soilmoisutre, the soil moisture 
!! calculated in sechiba.
!! Then, the function is ranged between 0.25 and 1:\n
!! \latexonly
!! \input{control_moist_func2.tex}
!! \endlatexonly
!! \n
!! RECENT CHANGE(S) : None
!!
!! RETURN VALUE : ::moistfunc_result
!! 
!! REFERENCE(S) : None
!!
!! FLOWCHART : None
!! \n
!_ ================================================================================================================================
  
  FUNCTION control_moist_func_moyano (npts, moist_in, zz_coef_deep, bulk_dens, clay, carbon_32l,veget_max) RESULT (moistfunc_result)

  !! 0. Variable and parameter declaration

    !! 0.1 Input variables

    INTEGER(i_std), INTENT(in)               :: npts                !! Domain size - number of grid pixel (unitless)
    REAL(r_std), DIMENSION(npts), INTENT(in) :: moist_in            !! relative humidity (unitless)
    REAL(r_std), DIMENSION(npts), INTENT(in)                    :: clay               !! Clay fraction (unitless, 0-1) 
    REAL(r_std), DIMENSION(npts), INTENT(in)                    :: bulk_dens          !! Variable local of bulk density for the moment must change in the futur (kg m-3)
    REAL(r_std), DIMENSION(npts,ncarb,nvm,ndeep), INTENT(in)     :: carbon_32l             !! Soil carbon pools: active, slow, or passive, \f$(gC m^{2})$\f
    REAL(r_std),DIMENSION(npts,nvm),INTENT(in)                  :: veget_max          !! Maximum fraction of vegetation type including 
                                                                                      !! non-biological fraction (unitless)
    REAL(r_std), DIMENSION(ndeep),   INTENT (in)          :: zz_coef_deep      !! deep vertical profile
    !! 0.2 Output variables

    REAL(r_std), DIMENSION(npts)          :: moistfunc_result    !! Moisture control factor (0-1, unitless)

    !! 0.3 Modified variables

    !! 0.4 Local variables
   REAL(r_std), DIMENSION(npts)           :: total_soc              !! Total soil organic carbon for a grid pixel (g-C g-1 soil)
   INTEGER(i_std)                         :: k,i,j                  !! Indices
   INTEGER, PARAMETER                     :: nummoist = 120         !! We used numoist then divived by 100. because to calculate the function
                                                                    !! we need to predict PRsr for all the possible soil moisture values
   REAL(r_std), DIMENSION(npts,nummoist)  :: PRsr                   !! Proportional response or soil respiration at moist_in 
   REAL(r_std), DIMENSION(npts,nummoist)  :: SR                     !! Soil respiration at moist_in to facilitate the understanding regarding 
                                                                    !! the Moyano et al paper we keep the same nomenclature than in the paper
                                                                    !! but **BE CAREFUL** it does not correspond to the variable resp_hetero_soil
                                                                    !! or resp_hetero_litter in ORCHIDEE
   REAL(r_std), DIMENSION(0:nbdl)   :: z_soil                 !! Soil levels (m)
   REAL(r_std), DIMENSION(0:ndeep)   :: zf_soil                 !! Soil levels (m)

!$OMP THREADPRIVATE(z_soil)
   REAL(r_std), DIMENSION(npts,nummoist)  :: moistfunc              !! An intermediate variable to calculate the Moisture control factor
   INTEGER(i_std)                         :: ind                    !! A local variable to know what is the index of the max value for the statistical function
   INTEGER(i_std), DIMENSION(npts)        :: ind_i                  !! A local variable to know what is the index of the max value for the 
                                                                    !! statistical function at each points
   REAL(r_std),ALLOCATABLE,SAVE,DIMENSION(:,:)    :: moistfunc_below_1 !! A allocatable variable to store the value of moistfunc that are below the max value
                                                                       !! to then rescale at is it done in Moyano et al. 2012 BG
!$OMP THREADPRIVATE(moistfunc_below_1)
   INTEGER(i_std)                         :: ier                    !! Check errors in netcdf call (unitless)
   LOGICAL                                :: l_error                !! Check errors in netcdf call

!_ ================================================================================================================================

       !! 1.3 soil levels
       z_soil(0) = zero
       z_soil(1:nbdl) = diaglev(1:nbdl)
!!SIMON ADDED MICT
       zf_soil(1:ndeep) = zz_coef_deep(:)
       zf_soil(0) = 0.


    ! In Moyano et al. 2012 BG, the function obtained is based on soil 
    ! incubations were litter is generally manually removed, therefore we used 
    ! only the variable carbon corresponding to the soil organic carbon even
    ! if some litter (metabolic litter) is not easy to remove manually since it
    ! corresponds to roots exudates. Therefore, we probably underestimate a bit
    ! the soil organic carbon compared to what is used in Moyano et al., 2012
    ! BG.

 PRsr(:,:) = zero
 SR(:,:) = zero
 moistfunc(:,:) = zero
    l_error = .FALSE.

    total_soc(:) = zero
    DO k = 1,nvm
       DO j = 1,ndeep
       total_soc(:) =  total_soc(:) + &
                      ((carbon_32l(:,iactive,k,j)*veget_max(:,k) + &
                       carbon_32l(:,islow,k,j)*veget_max(:,k) + &
                       carbon_32l(:,ipassive,k,j)*veget_max(:,k))* &
                       ((zf_soil(j)-zf_soil(j-1))/zf_soil(ndeep))) / &
                      (bulk_dens(:) ) 
       ENDDO
    ENDDO

     DO k = 1,nummoist

        PRsr(:,k) = 1.11066-0.83344*(k/100.) + 1.48095*((k/100.)**2) - 1.02959*((k/100.)**3) + 0.07995*clay(:) + 1.27892*total_soc(:)

     ENDDO

        SR(:,1)=PRsr(:,1)
     DO k=2,nummoist
        SR(:,k)= SR(:,k-1)* PRsr(:,k)
     ENDDO

     DO i = 1,npts
         DO k= 1, nummoist
                moistfunc(i,k) = SR(i,k)/MAXVAL(SR(i,:))
         ENDDO
    ENDDO

       ind_i(:) = MAXLOC(moistfunc(:,:),DIM=2)

     DO i = 1,npts
         ind=ind_i(i)

    ALLOCATE(moistfunc_below_1(npts,ind),stat=ier)
    l_error = l_error .OR. (ier /= 0)
    IF (l_error) THEN
       WRITE(numout,*) 'Memory allocation error for moistfunc_below_1. '
    ENDIF

         DO k= 1,ind
            moistfunc_below_1(i,k)= moistfunc(i,k)
         ENDDO

         DO k= 1,ind           
            moistfunc(i,k)=moistfunc(i,k) - MINVAL(moistfunc_below_1(i,:))
         ENDDO

         DO k= 1,ind
            moistfunc_below_1(i,k)= moistfunc(i,k)
         ENDDO

         DO k=1,ind

            moistfunc(i,k)=moistfunc(i,k)/MAXVAL(moistfunc_below_1(i,:))
         ENDDO

    IF (ALLOCATED(moistfunc_below_1)) DEALLOCATE(moistfunc_below_1)

    ENDDO
    DO i=1,npts
               IF (NINT(moist_in(i)*100.) .GT. zero) THEN
               moistfunc_result(i) = moistfunc(i,NINT(moist_in(i)*100.))
               ELSE
               moistfunc_result(i) = zero
               ENDIF
    ENDDO

  END FUNCTION control_moist_func_moyano


!! ================================================================================================================================
!! FUNCTION     : control_moist_func
!!
!>\BRIEF        Calculate moisture control for litter and soil C decomposition
!!
!! DESCRIPTION  : Calculate moisture control factor applied
!! to litter decomposition and to soil carbon decomposition in
!! stomate_soilcarbon.f90 using the following equation: \n
!! \latexonly
!! \input{control_moist_func1.tex}
!! \endlatexonly
!! \n
!! with M the moisture control factor and soilmoisutre, the soil moisture 
!! calculated in sechiba.
!! Then, the function is ranged between Moistcont_min and 1:\n
!! \latexonly
!! \input{control_moist_func2.tex}
!! \endlatexonly
!! \n
!! RECENT CHANGE(S) : None
!!
!! RETURN VALUE : ::moistfunc_result
!! 
!! REFERENCE(S) : None
!!
!! FLOWCHART : None
!! \n
!_ ================================================================================================================================
  
  FUNCTION control_moist_func (npts, moist_in) RESULT (moistfunc_result)

  !! 0. Variable and parameter declaration
    
    !! 0.1 Input variables
          
    INTEGER(i_std), INTENT(in)               :: npts                !! Domain size - number of grid pixel (unitless)
    REAL(r_std), DIMENSION(npts), INTENT(in) :: moist_in            !! relative humidity (unitless)

    !! 0.2 Output variables
   
    REAL(r_std), DIMENSION(npts)             :: moistfunc_result    !! Moisture control factor (0.25-1, unitless)

    !! 0.3 Modified variables

    !! 0.4 Local variables

!_ ================================================================================================================================

    moistfunc_result(:) = -moist_coeff(1) * moist_in(:) * moist_in(:) + moist_coeff(2)* moist_in(:) - moist_coeff(3)
    moistfunc_result(:) = MAX( moistcont_min, MIN( un, moistfunc_result(:) ) )

  END FUNCTION control_moist_func


!! ================================================================================================================================
!! %%%%% SIMON:: NEED TO INTEGRATE IN ORCHILEAK TEMP FUNCTION using TAU AS WELL FOR DOC 
!!
!!
!!
!!
!!FUNCTION     : control_temp_func
!!
!>\BRIEF        Calculate temperature control for litter and soild C decomposition
!!
!! DESCRIPTION  : Calculate temperature control factor applied
!! to litter decomposition and to soil carbon decomposition in
!! stomate_soilcarbon.f90 using the following equation: \n
!! \latexonly
!! \input{control_temp_func1.tex}
!! \endlatexonly
!! \n
!! with T the temperature control factor, temp the temperature in Kelvin of 
!! the air (for aboveground litter) or of the soil (for belowground litter 
!! and soil)
!! Then, the function is limited in its maximal range to 1:\n
!! \latexonly
!! \input{control_temp_func2.tex}
!! \endlatexonly
!! \n
!! RECENT CHANGE(S) : None
!!
!! RETURN VALUE: ::tempfunc_result
!!
!! REFERENCE(S) : None
!!
!! FLOWCHART : None
!! \n
!_ ================================================================================================================================

  FUNCTION control_temp_func (npts, temp_in, frozen_respiration_func) RESULT (tempfunc_result) 

  !! 0. Variable and parameter declaration
    
    !! 0.1 Input variables
    INTEGER(i_std), INTENT(in)                 :: npts            !! Domain size - number of land pixels (unitless)
    REAL(r_std), DIMENSION(npts), INTENT(in)   :: temp_in         !! Temperature (K)
    INTEGER(i_std), INTENT(in)                 :: frozen_respiration_func
    !! 0.2 Output variables
    REAL(r_std), DIMENSION(npts)               :: tempfunc_result !! Temperature control factor (0-1, unitless)

    !! 0.3 Modified variables

    !! 0.4 Local variables

!_ ================================================================================================================================
! write (numout, *) "Case is CASE:", frozen_respiration_func   
    SELECT CASE(frozen_respiration_func)

    CASE(0) !!! this is the standard ORCHIDEE state

    tempfunc_result(:) = exp( soil_Q10 * ( temp_in(:) - (ZeroCelsius+tsoil_ref)) / Q10 )
    tempfunc_result(:) = MIN( un, tempfunc_result(:) )
    CASE(1)  !!! cutoff respiration when T < -1C
!write (numout,*) "temp_in Max: ", maxval(temp_in) 
!write (numout,*) "temp_in Min: ", minval(temp_in) 
       WHERE (temp_in(:) .GT. ZeroCelsius ) !!! normal as above
          tempfunc_result(:) = EXP( 0.69 * ( temp_in(:) - (ZeroCelsius+30.) ) / 10. )
       ELSEWHERE (temp_in(:) .GT. ZeroCelsius - 1. )  !!! linear dropoff to zero
          tempfunc_result(:) = (temp_in(:) - (ZeroCelsius - 1.)) * EXP( 0.69 * ( ZeroCelsius - (ZeroCelsius+30.) ) / 10. )
       ELSEWHERE  !!! zero
          tempfunc_result(:) = zero
       endwhere
!write (numout,*) "temp_in2 Max: ",maxval(tempfunc_result) 
!write (numout,*) "temp_in2 Min: ",minval(tempfunc_result) 
       tempfunc_result(:) = MAX(MIN( 1._r_std, tempfunc_result(:) ), zero)

    CASE(2)  !!! cutoff respiration when T < -3C
!  write (numout, *) "line 1965"  
       WHERE (temp_in(:) .GT. ZeroCelsius ) !!! normal as above
          tempfunc_result(:) = EXP( 0.69 * ( temp_in(:) - (ZeroCelsius+30.) ) / 10. )
       ELSEWHERE (temp_in(:) .GT. ZeroCelsius - 3. )  !!! linear dropoff to zero
          tempfunc_result(:) = ((temp_in(:) - (ZeroCelsius - 3.))/3.) * EXP( 0.69 * ( ZeroCelsius - (ZeroCelsius+30.) ) / 10. )
       ELSEWHERE  !!! zero
          tempfunc_result(:) = zero
       endwhere

    CASE(3)  !!! q10 = 100 when below zero
 ! write (numout, *) "line 1975"  
       WHERE (temp_in(:) .GT. ZeroCelsius ) !!! normal as above
          tempfunc_result(:) = EXP( 0.69 * ( temp_in(:) - (ZeroCelsius+30.) ) / 10. )
       ELSEWHERE
           tempfunc_result(:) = EXP( 4.605 * ( temp_in(:) - (ZeroCelsius) ) / 10.) * EXP( 0.69 * ( -30. ) / 10. )
       endwhere

    CASE(4)  !!! q10 = 1000 when below zero
!  write (numout, *) "line 1984"  
       WHERE (temp_in(:) .GT. ZeroCelsius ) !!! normal as above
          tempfunc_result(:) = EXP( 0.69 * ( temp_in(:) - (ZeroCelsius+30.) ) / 10. )
       ELSEWHERE
	  tempfunc_result(:) = EXP( 6.908 * ( temp_in(:) - (ZeroCelsius) ) / 10.) * EXP( 0.69 * ( -30. ) / 10. )
       endwhere

    END SELECT
!    WRITE(numout,*) 'SIMON LITTER 2002 tempfunc_result Max> ', maxval(tempfunc_result)
!    WRITE(numout,*) 'SIMON LITTER 2002 tempfunc_result Min> ', minval(tempfunc_result)   
    tempfunc_result(:) = MAX(MIN( 1._r_std, tempfunc_result(:) ), zero)
  END FUNCTION control_temp_func

END MODULE stomate_litter
